<?php
/**
 * Checkout Class
 * All nessesary functions for the checkout
 * or retrieving checkout informations
 * 
 * @category    Payment Plugin
 * @package     paydirekt
 * @author      Logata Digital Solutions GmbH
 * @copyright   Logata Digital Solutions GmbH
 * @license     https://logata.com/paydirekt-lizenzbedingungen
 * @version     1.0.4
 * @link        https://www.paydirekt.de
 */

namespace Bitergo\PaydirektWooCommerce\Lib;

    const PAYDIREKT_MULTIREASON_KEY = "multireason";
    const PAYDIREKT_CODE_KEY = "code";
    const PAYDIREKT_REASON_KEY = "reason";
    const PAYDIREKT_MESSAGE_KEY = "message";
    const PAYDIREKT_DESCRIPTION_KEY = "description";
    const PAYDIREKT_UNPROCESSABLE_ENTITIY = "Unprocessable Entity";
    const PAYDIREKT_UNAUTHORIZED_KEY = "Unauthorized";
    const PAYDIREKT_UNAUTHORIZED_UP_KEY = "UNAUTHORIZED";
    const PAYDIREKT_CREATED_KEY = "Created";
    const PAYDIREKT_VALIDATIONERROR_KEY = "VALIDATION_ERROR";
    const PAYDIREKT_BADREQUEST_KEY = "Bad Request";
    const PAYDIREKT_ERROR_ACCESDENIED_KEY = "Der Zugriff wurde verweigert. ";
    const PAYDIREKT_MERCHANTBANKACCOUNT_LOCK_KEY = "MERCHANT_BANKACCOUNT_LOCKED";
    const PAYDIREKT_NOTFOUND_KEY = "Not Found";


    define("CHECKOUT_STATUS", json_encode(array(
        "201" => array(
            PAYDIREKT_CODE_KEY => 201,
            PAYDIREKT_REASON_KEY => PAYDIREKT_CREATED_KEY,
            PAYDIREKT_MESSAGE_KEY => "OK",
            PAYDIREKT_DESCRIPTION_KEY => "Der Checkout wurde angelegt. Anschließend muss ein Redirect "
            ."auf den in der Resource hinterlegten Link approve durchgeführt werden"),
        "400" => array(
            PAYDIREKT_CODE_KEY => 400,
            PAYDIREKT_MULTIREASON_KEY => array(
            PAYDIREKT_VALIDATIONERROR_KEY => array(
                PAYDIREKT_REASON_KEY => PAYDIREKT_BADREQUEST_KEY,
                PAYDIREKT_MESSAGE_KEY => PAYDIREKT_VALIDATIONERROR_KEY,
                PAYDIREKT_DESCRIPTION_KEY => "Der Request ist syntaktisch ungültig."),
            "CONVERSION_ERROR" => array(
                PAYDIREKT_REASON_KEY => PAYDIREKT_BADREQUEST_KEY,
                PAYDIREKT_MESSAGE_KEY => "CONVERSION_ERROR",
                PAYDIREKT_DESCRIPTION_KEY => "Der Request enthält ungültige Zeichen. Häufigste Ursache "
                ."hierfür ist, dass der Request nicht korrekt UTF-8 codiert ist. Falls die ungültigen "
                ."Zeichen einem Attribut im Request zugeordnet werden können, wird dieses im Feld path "
                ."genannt und der ungültige Wert im Feld content übermittelt."),
            ),
        ),
        "401" => array(
            PAYDIREKT_CODE_KEY => 401,
            PAYDIREKT_MULTIREASON_KEY => array(
            "ACCESS_TOKEN_EXPIRED" => array(
                PAYDIREKT_REASON_KEY => PAYDIREKT_UNAUTHORIZED_KEY,
                PAYDIREKT_MESSAGE_KEY => "ACCESS_TOKEN_EXPIRED",
                PAYDIREKT_DESCRIPTION_KEY => "Der Access Token ist abgelaufen."),
            PAYDIREKT_UNAUTHORIZED_UP_KEY => array(
                PAYDIREKT_REASON_KEY => PAYDIREKT_UNAUTHORIZED_KEY,
                PAYDIREKT_MESSAGE_KEY => PAYDIREKT_UNAUTHORIZED_UP_KEY,
                PAYDIREKT_DESCRIPTION_KEY => PAYDIREKT_ERROR_ACCESDENIED_KEY
                ."Bitte wenden Sie sich an den paydirekt-Support."),
            ),
        ),
        "422" => array(
            PAYDIREKT_CODE_KEY => 401,
            PAYDIREKT_MULTIREASON_KEY => array(
            PAYDIREKT_MERCHANTBANKACCOUNT_LOCK_KEY => array(
                PAYDIREKT_REASON_KEY => PAYDIREKT_UNPROCESSABLE_ENTITIY,
                PAYDIREKT_MESSAGE_KEY => PAYDIREKT_MERCHANTBANKACCOUNT_LOCK_KEY,
                PAYDIREKT_DESCRIPTION_KEY => "Das Bankkonto des Händlers wurde gesperrt und es "
                ."können keine neue Checkouts oder Captures angelegt werden. "
                ."Der Händler sollte sich an den paydirekt-Support wenden."),
            "PSP_LOCKED" => array(
                PAYDIREKT_REASON_KEY => PAYDIREKT_UNPROCESSABLE_ENTITIY,
                PAYDIREKT_MESSAGE_KEY => "PSP_LOCKED",
                PAYDIREKT_DESCRIPTION_KEY => "Der Payment Service Provider (PSP) ist gesperrt, "
                ."es können keine neuen Checkouts oder Captures angelegt werden."),
            )
        )
    )));



    define("CAPTURE_STATUS", json_encode( array(
        "201" => array(
            PAYDIREKT_CODE_KEY => 201,
            PAYDIREKT_REASON_KEY => PAYDIREKT_CREATED_KEY,
            PAYDIREKT_MESSAGE_KEY => "OK",
            PAYDIREKT_DESCRIPTION_KEY => "Der Capture wurde erfolgreich angelegt"),
        "400" => array(
            PAYDIREKT_CODE_KEY => 400,
            PAYDIREKT_REASON_KEY => PAYDIREKT_BADREQUEST_KEY,
            PAYDIREKT_MESSAGE_KEY => PAYDIREKT_VALIDATIONERROR_KEY,
            PAYDIREKT_DESCRIPTION_KEY => "Der Request ist syntaktisch ungültig"),
        "401" => array(
            PAYDIREKT_CODE_KEY => 401,
            PAYDIREKT_REASON_KEY => PAYDIREKT_UNAUTHORIZED_KEY,
            PAYDIREKT_MESSAGE_KEY => PAYDIREKT_UNAUTHORIZED_UP_KEY,
            PAYDIREKT_DESCRIPTION_KEY => PAYDIREKT_ERROR_ACCESDENIED_KEY .
            "Bitte wenden Sie sich an den paydirekt Support"),
        "404" => array(
            PAYDIREKT_CODE_KEY => 404,
            PAYDIREKT_REASON_KEY => PAYDIREKT_NOTFOUND_KEY,
            PAYDIREKT_MESSAGE_KEY => "CHECKOUT_NOT_FOUND",
            PAYDIREKT_DESCRIPTION_KEY => "Der Checkout wurde nicht gefunden"),
        "422" => array(
            PAYDIREKT_CODE_KEY => 422,
            PAYDIREKT_MULTIREASON_KEY => array(
            "CAPTURE_AMOUNT_EXCEEDED" => array(
                PAYDIREKT_REASON_KEY => PAYDIREKT_UNPROCESSABLE_ENTITIY,
                PAYDIREKT_MESSAGE_KEY => "CAPTURE_AMOUNT_EXCEEDED",
                PAYDIREKT_DESCRIPTION_KEY => "Die Summe aller Captures übersteigt " .
                "den Gesamtbetrag des Checkouts"),
            "CAPTURE_CHECKOUT_WRONG_TYPE" => array(
                PAYDIREKT_REASON_KEY => PAYDIREKT_UNPROCESSABLE_ENTITIY,
                PAYDIREKT_MESSAGE_KEY => "CAPTURE_CHECKOUT_WRONG_TYPE",
                PAYDIREKT_DESCRIPTION_KEY => "Für diesen Checkout-Typ kann kein Capture angelegt werden"),
            "CAPTURE_ORDER_CLOSED" => array(
                PAYDIREKT_REASON_KEY => PAYDIREKT_UNPROCESSABLE_ENTITIY,
                PAYDIREKT_MESSAGE_KEY => "CAPTURE_ORDER_CLOSED",
                PAYDIREKT_DESCRIPTION_KEY => "Es wurde versucht, ein Capture für einen bereits geschlossenen " .
                "Checkout anzulegen"),
            "CAPTURE_ORDER_NOT_APPROVED" => array(
                PAYDIREKT_REASON_KEY => PAYDIREKT_UNPROCESSABLE_ENTITIY,
                PAYDIREKT_MESSAGE_KEY => "CAPTURE_ORDER_NOT_APPROVED",
                PAYDIREKT_DESCRIPTION_KEY => "Es wurde versucht, einen Capture für eine Order anzulegen, " .
                "die vom Kunden nicht bestätigt wurde"),
            "CAPTURE_NOT_AUTHORIZED" => array(
                PAYDIREKT_REASON_KEY => PAYDIREKT_UNPROCESSABLE_ENTITIY,
                PAYDIREKT_MESSAGE_KEY => "CAPTURE_NOT_AUTHORIZED",
                PAYDIREKT_DESCRIPTION_KEY => "Der Capture-Betrag wurde von der Käuferbank nicht autorisiert"),
            PAYDIREKT_MERCHANTBANKACCOUNT_LOCK_KEY => array(
                PAYDIREKT_REASON_KEY => PAYDIREKT_UNPROCESSABLE_ENTITIY,
                PAYDIREKT_MESSAGE_KEY => PAYDIREKT_MERCHANTBANKACCOUNT_LOCK_KEY,
                PAYDIREKT_DESCRIPTION_KEY => "Ihr Händlerkonto ist gesperrt. Bitte wenden Sie sich an den " .
                "paydirekt Support"),
            "CHECKOUT_REJECTED" => array(
                PAYDIREKT_REASON_KEY => PAYDIREKT_UNPROCESSABLE_ENTITIY,
                PAYDIREKT_MESSAGE_KEY => "CHECKOUT_REJECTED",
                PAYDIREKT_DESCRIPTION_KEY => "Der Checkout wurde abgelehnt. " .
                "Es kann kein Capture angelegt werden"),
            "ORDER_ALREADY_CLOSED" => array(
                PAYDIREKT_REASON_KEY => PAYDIREKT_UNPROCESSABLE_ENTITIY,
                PAYDIREKT_MESSAGE_KEY => "ORDER_ALREADY_CLOSED",
                PAYDIREKT_DESCRIPTION_KEY => "Die Bestellung ist bereits geschlossen."),
            "NOT_AN_ORDER" => array(
                PAYDIREKT_REASON_KEY => PAYDIREKT_UNPROCESSABLE_ENTITIY,
                PAYDIREKT_MESSAGE_KEY => "NOT_AN_ORDER",
                PAYDIREKT_DESCRIPTION_KEY => "Dieser Checkout ist nicht vom Typ ORDER."),
            "CHECKOUT_INVALIDATED" => array(
				PAYDIREKT_REASON_KEY => PAYDIREKT_UNPROCESSABLE_ENTITIY,
                PAYDIREKT_MESSAGE_KEY => "CHECKOUT_INVALIDATED",
                PAYDIREKT_DESCRIPTION_KEY => "Die Ausführung ist nicht möglich, da der Checkout mittlerweile abgelaufen ist " .
                "oder vom Kunden abgebrochen wurde. Die Ausführung muss innerhalb von 30 Minuten nach Anlage des Checkouts erfolgen.."),
            )
        )
    )));


    define("REFUND_STATUS", json_encode( array(
        "201" => array(
            PAYDIREKT_CODE_KEY => 201,
            PAYDIREKT_REASON_KEY => "Refund created",
            PAYDIREKT_MESSAGE_KEY => "OK",
            PAYDIREKT_DESCRIPTION_KEY => "Der Refund wurde erfolgreich angelegt. " .
            "Er befindet sich im Status PENDING"),
        "400" => array(
            PAYDIREKT_CODE_KEY => 400,
            PAYDIREKT_REASON_KEY => PAYDIREKT_BADREQUEST_KEY,
            PAYDIREKT_MESSAGE_KEY => PAYDIREKT_VALIDATIONERROR_KEY,
            PAYDIREKT_DESCRIPTION_KEY => "Der Request ist syntaktisch ungültig"),
        "401" => array(
            PAYDIREKT_CODE_KEY => 401,
            PAYDIREKT_REASON_KEY => PAYDIREKT_UNAUTHORIZED_KEY,
            PAYDIREKT_MESSAGE_KEY => PAYDIREKT_UNAUTHORIZED_UP_KEY,
            PAYDIREKT_DESCRIPTION_KEY => PAYDIREKT_ERROR_ACCESDENIED_KEY .
            "Bitte wenden Sie sich an den paydirekt Support"),
        "404" => array(
            PAYDIREKT_CODE_KEY => 404,
            PAYDIREKT_REASON_KEY => PAYDIREKT_NOTFOUND_KEY,
            PAYDIREKT_MESSAGE_KEY => "CHECKOUT_NOT_FOUND",
            PAYDIREKT_DESCRIPTION_KEY => "Der Checkout wurde nicht gefunden, " .
            "oder Sie haben keine Zugriff auf diesen Checkout"),
        "422" => array(
             PAYDIREKT_CODE_KEY => 422,
            "multireason" => array(
                "REFUND_AMOUNT_EXCEEDED" => array(
                    PAYDIREKT_REASON_KEY => PAYDIREKT_UNPROCESSABLE_ENTITIY,
                    PAYDIREKT_MESSAGE_KEY => "REFUND_AMOUNT_EXCEEDED",
                    PAYDIREKT_DESCRIPTION_KEY => "Die Summe aller Rückzahlungen übersteigt die maximale Rückzahlungssumme"
                ),
                "USER_DEBOARDED" => array(
                    PAYDIREKT_REASON_KEY => PAYDIREKT_UNPROCESSABLE_ENTITIY,
                    PAYDIREKT_MESSAGE_KEY => "USER_DEBOARDED",
                    PAYDIREKT_DESCRIPTION_KEY => "Der Käuferaccount wurde endgültig geschlossen"
                ),
            )
        ) 
    )));

    define("TOKEN_STATUS", json_encode( array(
        "200" => array(
            PAYDIREKT_CODE_KEY => 200,
            PAYDIREKT_REASON_KEY => PAYDIREKT_CREATED_KEY,
            PAYDIREKT_MESSAGE_KEY => "OK",
            PAYDIREKT_DESCRIPTION_KEY => "Access Token wurde erfolgreich erstellt."),
        "400" => array(
            PAYDIREKT_CODE_KEY => 400,
            PAYDIREKT_REASON_KEY => PAYDIREKT_BADREQUEST_KEY,
            PAYDIREKT_MESSAGE_KEY => "INVALID_GRANT",
            PAYDIREKT_DESCRIPTION_KEY => "Der X-Auth-Key bzw. X-Auth-Code fehlt oder ist ungültig"),
        "401" => array(
            PAYDIREKT_CODE_KEY => 401,
            "multireason" => array(
                "API_KEY_IN_REQUEST_UNKNOWN" => array(
                PAYDIREKT_REASON_KEY => PAYDIREKT_UNAUTHORIZED_KEY,
                PAYDIREKT_MESSAGE_KEY => "API_KEY_IN_REQUEST_UNKNOWN",
                PAYDIREKT_DESCRIPTION_KEY => "Der API-Key ist im paydirekt-System nicht hinterlegt."),
                "API_KEY_REQUEST_HEADER_INVALID" => array(
                PAYDIREKT_REASON_KEY => PAYDIREKT_UNAUTHORIZED_KEY,
                PAYDIREKT_MESSAGE_KEY => "API_KEY_REQUEST_HEADER_INVALID",
                PAYDIREKT_DESCRIPTION_KEY => "Die Anfrage enthält mehr als einen X-Auth-Key."),
                "API_KEY_IN_REQUEST_INACTIVE" => array(
                PAYDIREKT_REASON_KEY => PAYDIREKT_UNAUTHORIZED_KEY,
                PAYDIREKT_MESSAGE_KEY => "API_KEY_IN_REQUEST_INACTIVE",
                PAYDIREKT_DESCRIPTION_KEY => "Der API-Key ist deaktiviert."),
                "API_KEY_REQUEST_SIGNATURE_INVALID" => array(
                PAYDIREKT_REASON_KEY => PAYDIREKT_UNAUTHORIZED_KEY,
                PAYDIREKT_MESSAGE_KEY => "API_KEY_REQUEST_SIGNATURE_INVALID",
                PAYDIREKT_DESCRIPTION_KEY => "Der X-Auth-Code ist falsch oder leer.")
            ),
        )
    ) ));

    define("UTILS_STATUS", json_encode( array(
        "400" => array(
            PAYDIREKT_CODE_KEY => 400,
            PAYDIREKT_REASON_KEY => PAYDIREKT_BADREQUEST_KEY,
            PAYDIREKT_MESSAGE_KEY => PAYDIREKT_BADREQUEST_KEY,
            PAYDIREKT_DESCRIPTION_KEY => "Der Request wurde nicht angenommen."),
        "401" => array(
            PAYDIREKT_CODE_KEY => 401,
            PAYDIREKT_REASON_KEY => PAYDIREKT_UNAUTHORIZED_KEY,
            PAYDIREKT_MESSAGE_KEY => PAYDIREKT_UNAUTHORIZED_KEY,
            PAYDIREKT_DESCRIPTION_KEY => "Es wurde versucht, auf eine Ressource zuzugreifen, die geschützt ist."),
        "403" => array(
            PAYDIREKT_CODE_KEY => 403,
            PAYDIREKT_REASON_KEY => "Forbidden",
            PAYDIREKT_MESSAGE_KEY => "Forbidden",
            PAYDIREKT_DESCRIPTION_KEY => "Der Zugriff ist auf diese Ressource mit der verwendeten HTTP-Methode nicht erlaubt."),
        "404" => array(
            PAYDIREKT_CODE_KEY => 404,
            PAYDIREKT_REASON_KEY => PAYDIREKT_NOTFOUND_KEY,
            PAYDIREKT_MESSAGE_KEY => PAYDIREKT_NOTFOUND_KEY,
            PAYDIREKT_DESCRIPTION_KEY => "Unter dieser URL kennt der Server keine Ressource."),
        "410" => array(
            PAYDIREKT_CODE_KEY => 410,
            PAYDIREKT_REASON_KEY => "Gone",
            PAYDIREKT_MESSAGE_KEY => "Gone",
            PAYDIREKT_DESCRIPTION_KEY => "Die API steht in dieser Version nicht mehr zur Verfügung."),
        "422" => array(
            PAYDIREKT_CODE_KEY => 422,
            PAYDIREKT_REASON_KEY => PAYDIREKT_UNPROCESSABLE_ENTITIY,
            PAYDIREKT_MESSAGE_KEY => PAYDIREKT_UNPROCESSABLE_ENTITIY,
            PAYDIREKT_DESCRIPTION_KEY => "Es ist ein fachlicher Fehler aufgetreten."),
        "500" => array(
            PAYDIREKT_CODE_KEY => 500,
            PAYDIREKT_REASON_KEY => "Internal Server Error",
            PAYDIREKT_MESSAGE_KEY => "Internal Server Error",
            PAYDIREKT_DESCRIPTION_KEY => "Es ist ein serverseitiger Fehler aufgetreten."),
        "503" => array(
            PAYDIREKT_CODE_KEY => 503,
            PAYDIREKT_REASON_KEY => "Service Unavailable",
            PAYDIREKT_MESSAGE_KEY => "Service Unavailable",
            PAYDIREKT_DESCRIPTION_KEY => "Das paydirekt System ist vorübergehend nicht erreichbar.")
    )));
