<?php
/**
 * Express Checkout Class
 * All nessesary functions for the express checkout
 * or retrieving express checkout informations
 * 
 * @category    Payment Plugin
 * @package     paydirekt
 * @author      Logata Digital Solutions GmbH
 * @copyright   Logata Digital Solutions GmbH
 * @license     https://logata.com/paydirekt-lizenzbedingungen
 * @version     1.0.4
 * @link        https://www.paydirekt.de
 */

namespace Bitergo\PaydirektWooCommerce\Lib;
use Bitergo\PaydirektWooCommerce\Lib\Utils;

class Express
{
    const PAYDIREKT_EXPRESS_CHECKOUT_ENDPOINT_SANDBOX = "https://api.sandbox.paydirekt.de/api/checkout/v1/checkouts";
    const PAYDIREKT_EXPRESS_CHECKOUT_ENDPOINT_LIVE = "https://api.paydirekt.de/api/checkout/v1/checkouts";

    /**
     * Execute the checkout and sends the new merchantOrderReference number for the checkout
     *
     * @param string $token
     * @param string $termsAcceptedTimestamp
     * @param string $merchantOrderReferenceNumber
     * @param bool $liveSystem
     * @return void
     */
    public static function execute($token, $checkoutId, $liveSystem, $termsAcceptedTimestamp, $merchantOrderReferenceNumber)
    {

        $payload = json_encode(
            array(
                "termsAcceptedTimestamp" => $termsAcceptedTimestamp,
                "merchantOrderReferenceNumber" => $merchantOrderReferenceNumber,
            )
        );

        if ($liveSystem === true) {
            $environment = static::PAYDIREKT_EXPRESS_CHECKOUT_ENDPOINT_LIVE;
        } else {
            $environment = static::PAYDIREKT_EXPRESS_CHECKOUT_ENDPOINT_SANDBOX;
        }

        $endpoint = $environment . "/" . $checkoutId . "/execute";
        return Utils::runCurl(Utils::getDefaultHeader($token), $payload, $endpoint, true);
    }
}
