<?php
/**
 * ReportRequestModel class
 *
 * @category    Payment Plugin
 * @package     paydirekt
 * @author      Logata Digital Solutions GmbH
 * @copyright   Logata Digital Solutions GmbH
 * @license     https://logata.com/paydirekt-lizenzbedingungen
 * @version     1.0.4
 * @link        https://www.paydirekt.de
 */

namespace Bitergo\PaydirektWooCommerce\Lib\models;
use Bitergo\PaydirektWooCommerce\Lib\Utils;

class ReportRequestModel
{

    const PAYDIREKT_REPORT_FROM = "from";
    const PAYDIREKT_REPORT_TO = "to";
    const PAYDIREKT_REPORT_FIELDS = "fields";
    const PAYDIREKT_REPORT_RECONCILIATIONREFERENCES = "reconciliationReferences";
    const PAYDIREKT_REPORT_PAYMENTINFORMATIONIDS = "paymentInformationIds";
    const PAYDIREKT_REPORT_MERCHANTREFERENCENUMBERS = "merchantReferenceNumbers";
    const PAYDIREKT_REPORT_CHECKOUTINVOICENUMBERS = "checkoutInvoiceNumbers";
    const PAYDIREKT_REPORT_CAPTUREINVOICENUMBERS = "captureInvoiceNumbers";
    /**
     * Timestamp in ISO 8061 Format
     *
     * @var string
     */
    private $from;
    /**
     * Timestamp in ISO 8061 Format
     *
     * @var string
     */
    private $to;
    /**
     * Array with column titles
     *
     * @var array
     */
    private $fields;
    /**
     * Array with reconciliationsreferences
     *
     * @var array
     */
    private $reconciliationReferences;
    /**
     * Array with paymentinformationids
     *
     * @var array
     */
    private $paymentInformationIds;
    /**
     * Array with merchentreferencenumbers
     *
     * @var array
     */
    private $merchantReferenceNumbers;
    /**
     * Array with checkoutinvoicenumbers
     *
     * @var array
     */
    private $checkoutInvoiceNumbers;
    /**
     * Array with captureinvoicenumbers
     *
     * @var array
     */
    private $captureInvoiceNumbers;

    /**
     * get from date
     *
     * @return void
     */
    public function getFrom()
    {
        return $this->from;
    }

    /**
     * set from Date
     *
     * @param date $from
     * @return void
     */
    public function setFrom($from)
    {
        $this->from = $from;
    }

    /**
     * get to date
     *
     * @return void
     */
    public function getTo()
    {
        return $this->to;
    }

    /**
     * set to date
     *
     * @param date $to
     * @return void
     */
    public function setTo($to)
    {
        $this->to = $to;
    }

    /**
     * get fields for csv header
     *
     * @return void
     */
    public function getFields()
    {
        return $this->fields;
    }

    /**
     * set fields for csv header
     *
     * @param array $fields
     * @return void
     */
    public function setFields($fields)
    {
        $this->fields = $fields;
    }

    /**
     * add fields into array
     *
     * @param string $fields
     * @return void
     */
    public function addFields($fields)
    {
        if (is_null($this->fields)) {
            $this->fields = array();
        }
        $this->fields[] = $fields;
    }

    /**
     * get Reconciliationreferences
     *
     * @return void
     */
    public function getReconciliationReferences()
    {
        return $this->reconciliationReferences;
    }

    /**
     * set reconciliationreferences
     *
     * @param array $reconciliationReferences
     * @return void
     */
    public function setReconciliationReferences($reconciliationReferences)
    {
        $this->reconciliationReferences = $reconciliationReferences;
    }

    /**
     * add reconciliationReferences into array
     *
     * @param string $reconciliationReferences
     * @return void
     */
    public function addReconciliationReferences($reconciliationReferences)
    {
        if (is_null($this->reconciliationReferences)) {
            $this->reconciliationReferences = array();
        }
        $this->reconciliationReferences[] = $reconciliationReferences;
    }

    /**
     * get paymentinformationids
     *
     * @return void
     */
    public function getPaymentInformationIds()
    {
        return $this->paymentInformationIds;
    }

    /**
     * set paymentinformationids
     *
     * @param array $paymentInformationIds
     * @return void
     */
    public function setPaymentInformationIds($paymentInformationIds)
    {
        $this->paymentInformationIds = $paymentInformationIds;
    }

    /**
     * add paymentInformationIds into array
     *
     * @param string $paymentInformationIds
     * @return void
     */
    public function addPaymentInformationIds($paymentInformationIds)
    {
        if (is_null($this->paymentInformationIds)) {
            $this->paymentInformationIds = array();
        }
        $this->paymentInformationIds[] = $paymentInformationIds;
    }

    /**
     * get merchantreferencenumbers
     *
     * @return void
     */
    public function getMerchantReferenceNumbers()
    {
        return $this->merchantReferenceNumbers;
    }

    /**
     * set merchantreferencenumbers
     *
     * @param array $merchantReferenceNumbers
     * @return void
     */
    public function setMerchantReferenceNumbers($merchantReferenceNumbers)
    {
        $this->merchantReferenceNumbers = $merchantReferenceNumbers;
    }

    /**
     * add merchantReferenceNumbers into array
     *
     * @param string $merchantReferenceNumbers
     * @return void
     */
    public function addMerchantReferenceNumbers($merchantReferenceNumbers)
    {
        if (is_null($this->merchantReferenceNumbers)) {
            $this->merchantReferenceNumbers = array();
        }
        $this->merchantReferenceNumbers[] = $merchantReferenceNumbers;
    }

    /**
     * get checkoutinvoicenumbers
     *
     * @return void
     */
    public function getCheckoutInvoiceNumbers()
    {
        return $this->checkoutInvoiceNumbers;
    }

    /**
     * set checkoutinvoicenumbers
     *
     * @param array $checkoutInvoiceNumbers
     * @return void
     */
    public function setCheckoutInvoiceNumbers($checkoutInvoiceNumbers)
    {
        $this->checkoutInvoiceNumbers = $checkoutInvoiceNumbers;
    }

    /**
     * add checkoutInvoiceNumbers into array
     *
     * @param string $checkoutInvoiceNumbers
     * @return void
     */
    public function addCheckoutInvoiceNumbers($checkoutInvoiceNumbers)
    {
        if (is_null($this->checkoutInvoiceNumbers)) {
            $this->checkoutInvoiceNumbers = array();
        }
        $this->checkoutInvoiceNumbers[] = $checkoutInvoiceNumbers;
    }

    /**
     * get captureinvoicenumbers
     *
     * @return void
     */
    public function getCaptureInvoiceNumbers()
    {
        return $this->captureInvoiceNumbers;
    }

    /**
     * set captureinvoicenumbers
     *
     * @param array $captureInvoiceNumbers
     * @return void
     */
    public function setCaptureInvoiceNumbers($captureInvoiceNumbers)
    {
        $this->captureInvoiceNumbers = $captureInvoiceNumbers;
    }

    /**
     * add captureInvoiceNumbers into array
     *
     * @param string $captureInvoiceNumbers
     * @return void
     */
    public function addCaptureInvoiceNumbers($captureInvoiceNumbers)
    {
        if (is_null($this->captureInvoiceNumbers)) {
            $this->captureInvoiceNumbers = array();
        }
        $this->captureInvoiceNumbers[] = $captureInvoiceNumbers;
    }

    /**
     * check if input is a valid array or json
     *
     * @param array $lists
     * @return void
     */
    public function validateLists($lists)
    {
        if (isset($lists)) {
            $validateBool = false;
            if (is_array($lists)) {
                $lists = implode(",", $lists);
                $validateBool = true;
            }
            if (Utils::jsonValidate($lists)) {
                $reconciliationArray = json_decode($lists, true);
                if (is_array($reconciliationArray)) {
                    $lists = implode(",", $reconciliationArray);
                }
                $validateBool = true;
            }
            if (!$validateBool) {
                $lists = '';
                throw new \InvalidArgumentException('Die Eingabe für die Reconciliationreference ist nicht valide und wird geleert.');
            }
        }
        return $lists;
    }

    /**
     * check date is ISO8601 format
     *
     * @param date $date
     * @return void
     */
    public function validateDate($date)
    {
        if (isset($date)) {
            if (!Utils::isISO8601Date($date)) {
                $date = '';
                throw new \InvalidArgumentException('Das eingebene Datum ist nicht ISO8061 valide und wird geleert.');
            } else {
                return $date;
            }
        }
    }

    public function validateObject()
    {
        if (!empty($this->from)) {
            $this->from = $this->validateDate($this->from);
        }
        if (!empty($this->to)) {
            $this->to = $this->validateDate($this->to);
        }
        if (!empty($this->fields)) {
            $this->fields = $this->validateLists($this->fields);
        }
        if (!empty($this->reconciliationReferences)) {
            $this->reconciliationReferences = $this->validateLists($this->reconciliationReferences);
        }
        if (!empty($this->paymentInformationIds)) {
            $this->paymentInformationIds = $this->validateLists($this->paymentInformationIds);
        }
        if (!empty($this->merchantReferenceNumbers)) {
            $this->merchantReferenceNumbers = $this->validateLists($this->merchantReferenceNumbers);
        }
        if (!empty($this->checkoutInvoiceNumbers)) {
            $this->checkoutInvoiceNumbers = $this->validateLists($this->captureInvoiceNumbers);
        }
        if (!empty($this->captureInvoiceNumbers)) {
            $this->captureInvoiceNumbers = $this->validateLists($this->captureInvoiceNumbers);
        }
    }

    /**
     * create valid url query, if invalid parametres throw exeption
     *
     * @return void
     */
    public function createUrl()
    {
        $payload = array();
        try {
            $this->validateObject();
            $payload[static::PAYDIREKT_REPORT_FROM] = $this->from;
            $payload[static::PAYDIREKT_REPORT_TO] = $this->to;
            $payload[static::PAYDIREKT_REPORT_FIELDS] = $this->fields;
            $payload[static::PAYDIREKT_REPORT_RECONCILIATIONREFERENCES] = $this->reconciliationReferences;
            $payload[static::PAYDIREKT_REPORT_PAYMENTINFORMATIONIDS] = $this->paymentInformationIds;
            $payload[static::PAYDIREKT_REPORT_MERCHANTREFERENCENUMBERS] = $this->merchantReferenceNumbers;
            $payload[static::PAYDIREKT_REPORT_CHECKOUTINVOICENUMBERS] = $this->checkoutInvoiceNumbers;
            $payload[static::PAYDIREKT_REPORT_CAPTUREINVOICENUMBERS] = $this->captureInvoiceNumbers;
            return http_build_query($payload);
        } catch (\InvalidArgumentException $ex) {
            throw new \InvalidArgumentException('Es sind falsche Such-Kriterien eingeben worden.');
        }
    }
}
