<?php
/**
 * Refund class
 * Used to Refund checkouts with the paydirekt api
 *
 * @category    Payment Plugin
 * @package     paydirekt
 * @author      Logata Digital Solutions GmbH
 * @copyright   Logata Digital Solutions GmbH
 * @license     https://logata.com/paydirekt-lizenzbedingungen
 * @version     1.0.4
 * @link        https://www.paydirekt.de
 */

namespace Bitergo\PaydirektWooCommerce\Lib;
use Bitergo\PaydirektWooCommerce\Lib\Utils;

class Refund
{
    const PAYDIREKT_CHECKOUT_ENDPOINT_SANDBOX = "https://api.sandbox.paydirekt.de/api/checkout/v1/checkouts";
    const PAYDIREKT_CHECKOUT_ENDPOINT_LIVE = "https://api.paydirekt.de/api/checkout/v1/checkouts";
    const PAYDIREKT_CHECKOUTID_KEY = "checkoutId";
    const PAYDIREKT_UTILS_INCLUDE = "utils.php";

    const PAYDIREKT_CODE_KEY = "code";
    const PAYDIREKT_REASON_KEY = "reason";
    const PAYDIREKT_MESSAGE_KEY = "message";
    const PAYDIREKT_DESCRIPTION_KEY = "description";

    const STATUS = REFUND_STATUS;

    /**
     * Creates a refund, based on the checkoutId.
     * Returns the result from paydirekt.
     * If there arer any errors, the status codes are listed on in the STATUS constant.
     *
     * @param string $token
     * @param string $checkoutID
     * @param array $payloadData
     * @param boolean $liveSystem
     * @return void
     */
    public static function createRefund($token, $checkoutID, $payloadData, $liveSystem)
    {
        require_once(static::PAYDIREKT_UTILS_INCLUDE);
        $payload = array();
        foreach ($payloadData as $key => $value) {
            if (!empty($value) && ($key <> "action") && ($key <> static::PAYDIREKT_CHECKOUTID_KEY)) {
                $payload[$key] = $value;
            }
        }
        $payload = json_encode($payload);
        if ($liveSystem === true) {
            $Environment = self::PAYDIREKT_CHECKOUT_ENDPOINT_LIVE;
        } else {
            $Environment = self::PAYDIREKT_CHECKOUT_ENDPOINT_SANDBOX;
        }
        $endpoint = $Environment . "/" . $checkoutID . "/refunds";
        return Utils::runCurl(Utils::getDefaultHeader($token), $payload, $endpoint, true);
    }
    public static function retrieveRefund($token, $checkoutId, $refundId, $liveSystem)
    {
        require_once(static::PAYDIREKT_UTILS_INCLUDE);
        if ($liveSystem === true) {
            $Environment = self::PAYDIREKT_CHECKOUT_ENDPOINT_LIVE;
        } else {
            $Environment = self::PAYDIREKT_CHECKOUT_ENDPOINT_SANDBOX;
        }
        $endpoint = $Environment . "/" . $checkoutId . "/refunds/" . $refundId;
        return Utils::runCurl(Utils::getDefaultHeader($token), false, $endpoint, false);
    }
}
