<?php
/**
 * Report class to get Reports from the paydirekt api
 *
 * @category    Payment Plugin
 * @package     paydirekt
 * @author      Logata Digital Solutions GmbH
 * @copyright   Logata Digital Solutions GmbH
 * @license     https://logata.com/paydirekt-lizenzbedingungen
 * @version     1.0.4
 * @link        https://www.paydirekt.de
 */

namespace Bitergo\PaydirektWooCommerce\Lib;
use Bitergo\PaydirektWooCommerce\Lib\Utils;

class Report
{
    const PAYDIREKT_REPORTS_ENDPOINT_SANDBOX =  "https://api.sandbox.paydirekt.de/api/reporting/v1/reports/transactions?";
    const PAYDIREKT_REPORTS_ENDPOINT_LIVE =  "https://api.paydirekt.de/api/reporting/v1/reports/transactions?";
    const PAYDIREKT_REPORT_FORMAT_JSON = "application/json";
    const PAYDIREKT_REPORT_FORMAT_CSV = "text/csv";

    /**
     * Creates a report
     *
     * @param string $token
     * @param boolean $liveSystem
     * @return void
     */
    public static function getReport($token, $liveSystem, $reportRequestModel = null)
    {
        require_once('utils.php');
        $payload = $reportRequestModel->createUrl();
        $header = array();
        array_push($header, "Accept: " .static::PAYDIREKT_REPORT_FORMAT_JSON);
        array_push($header, "Authorization: Bearer " .$token);
        if ($liveSystem === true) {
            $url = static::PAYDIREKT_REPORTS_ENDPOINT_LIVE.$payload;
        } else {
            $url = static::PAYDIREKT_REPORTS_ENDPOINT_SANDBOX.$payload;
        }
        return Utils::runCurl($header, false , $url, false);
    }
    /**
     * Creates a Report in CSV Format
     *
     * @param string $token
     * @param boolean $liveSystem
     * @param Object $reportRequestModel
     * @return void
     */
    public static function getReportCsv($token, $liveSystem, $reportRequestModel = null)
    {
        require_once('utils.php');
        $payload = $reportRequestModel->createUrl();
        $header = array();
        array_push($header, "Accept: " .static::PAYDIREKT_REPORT_FORMAT_CSV);
        array_push($header, "Authorization: Bearer " .$token);
        if ($liveSystem === true) {
            $url = static::PAYDIREKT_REPORTS_ENDPOINT_LIVE.$payload;
        } else {
            $url = static::PAYDIREKT_REPORTS_ENDPOINT_SANDBOX.$payload;
        }
        return Utils::runCurl($header, false , $url, false);
    }
}
