<?php
/**
 * @category    Payment Plugin
 * @package     paydirekt
 * @author      Logata Digital Solutions GmbH
 * @copyright   Logata Digital Solutions GmbH
 * @license     https://logata.com/paydirekt-lizenzbedingungen
 * @version     1.0.44
 * @link        https://www.paydirekt.de
 */

namespace Bitergo\PaydirektWooCommerce\classes;

use Bitergo\PaydirektWooCommerce\Lib\PaydirektLogger;
use Bitergo\PaydirektWooCommerce\classes\PaydirektUtils;

if (!defined('ABSPATH')) {
    exit;
}
class PaydirektCapture
{

    private $orderId;
    private $logger;
    private $settings;

    public function __construct()
    {
        $this->logger = PaydirektLogger::getInstance(get_class($this));

        wp_enqueue_script('paydirekt-utils', plugins_url('../resources/js/paydirekt-utils.js', __FILE__), array('jquery'), null, true);
        wp_enqueue_script('paydirekt-refund', plugins_url('../resources/js/paydirekt-capture.js', __FILE__), array('jquery'), null, true);

        $this->orderId = wc_sanitize_order_id($_GET['order_id']);
        $order = new \WC_Order($this->orderId);
        $this->settings = PaydirektUtils::getSettings($order);
        $this->render();
    }

    public function render()
    {
        $saveUrl = wp_nonce_url(admin_url('admin.php?page=paydirekt-orderview&order_id=' . $this->orderId), 'paydirekt-overview');
        $cancelUrl = wp_nonce_url(admin_url('admin.php?page=paydirekt-orderview&order_id=' . $this->orderId), 'paydirekt-overview');
    ?>
        <div class='wrap woocommerce'>
            <form action="<?php echo $saveUrl?>" method="post">
                <table class="form-table paydirekt-form">
                    <tbody>
                        <?php echo PaydirektUtils::createFormElementRow(PAYDIREKT_TEXT,
                                __("amount", PAYDIREKT_PAYMENT_ID),
                                "amount",
                                __("capture_amount_help", PAYDIREKT_PAYMENT_ID)
                            )?>
                        <?php echo PaydirektUtils::createFormElementRow(PAYDIREKT_CHECKBOX,
                                __("finalCapture", PAYDIREKT_PAYMENT_ID),
                                "finalCapture",
                                __("capture_finalcapture_help", PAYDIREKT_PAYMENT_ID)
                            )?>
                        <?php echo PaydirektUtils::createFormElementRow(PAYDIREKT_TEXT,
                            __("merchantCaptureReferenceNumber", PAYDIREKT_PAYMENT_ID),
                            "merchantCaptureReferenceNumber",
                            __("capture_merchantcapturereferencenumber_help", PAYDIREKT_PAYMENT_ID),
                            $this->settings[PAYDIREKT_PARAMETER_MERCHANT_RECONCILATION_REFERENCE_NUMBER]
                        )?>
                        <?php echo PaydirektUtils::createFormElementRow(PAYDIREKT_TEXT,
                            __("merchantReconciliationReferenceNumber", PAYDIREKT_PAYMENT_ID),
                            "merchantReconciliationReferenceNumber",
                            __("capture_merchantreconciliationreferencenumber_help", PAYDIREKT_PAYMENT_ID),
                            $this->settings[PAYDIREKT_PARAMETER_RECONCILIATIONNUMBER]
                        )?>
                        <?php echo PaydirektUtils::createFormElementRow(PAYDIREKT_TEXT,
                            __("captureInvoiceReferenceNumber", PAYDIREKT_PAYMENT_ID),
                            "captureInvoiceReferenceNumber",
                            __("capture_captureinvoicereferencenumber_help", PAYDIREKT_PAYMENT_ID)
                        )?>
                        <?php echo PaydirektUtils::createFormElementRow(PAYDIREKT_TEXT,
                            __("note", PAYDIREKT_PAYMENT_ID),
                            "note",
                            __("note_help", PAYDIREKT_PAYMENT_ID),
                            $this->settings[PAYDIREKT_PARAMETER_ORDERNOTE]
                        )?>
                    </tbody>
                </table>
                <div class="buttons">
                    <?php echo PaydirektUtils::createButtonElement($cancelUrl,
                        "button paydirekt-cancel-button",
                        __("cancel", PAYDIREKT_PAYMENT_ID),
                        "cancelCapture"
                    )?>
                    <?php echo PaydirektUtils::createFormElement("submit",
                        "saveCapture",
                        "button-primary paydirekt-save-button",
                        __("capture_save", PAYDIREKT_PAYMENT_ID)
                    )?>
                </div>
            </form>
        </div>
        <?php
}
}