<?php
/**
 * @category    Payment Plugin
 * @package     paydirekt
 * @author      Logata Digital Solutions GmbH
 * @copyright   Logata Digital Solutions GmbH
 * @license     https://logata.com/paydirekt-lizenzbedingungen
 * @version     1.0.44
 * @link        https://www.paydirekt.de
 */

namespace Bitergo\PaydirektWooCommerce\classes;

use Bitergo\PaydirektWooCommerce\Lib\Token;
use Bitergo\PaydirektWooCommerce\Lib\PaydirektLogger;
use Bitergo\PaydirektWooCommerce\Lib\Utils;

if (!defined('ABSPATH')) {
    exit;
}
class PaydirektConfigForm
{
    private $logger;
    public static function getForm()
    {
        if(is_admin()){
            wp_enqueue_script('paydirekt-utils', plugins_url('../resources/js/paydirekt-utils.js', __FILE__), array('jquery'), null, true);
            wp_enqueue_script('paydirekt-config-check', plugins_url('../resources/js/paydirekt-config-check.js', __FILE__), array('jquery'), null, true);
        }
        return array(
            'enabled' => array(
                PAYDIREKT_TITLE => __('Enable/Disable', PAYDIREKT_PAYMENT_ID),
                PAYDIREKT_TYPE => PAYDIREKT_CHECKBOX,
                PAYDIREKT_LABEL => __('Enable paydirekt', PAYDIREKT_PAYMENT_ID),
                PAYDIREKT_DEFAULT => 'no',
            ),
            PAYDIREKT_PARAMETER_PAYMENT_TITLE => array(
                PAYDIREKT_TITLE => __('Titel', PAYDIREKT_PAYMENT_ID),
                PAYDIREKT_TYPE => PAYDIREKT_TEXT,
                PAYDIREKT_DEFAULT => PAYDIREKT_PAYMENT_TITLE,
                PAYDIREKT_DESCRIPTION => 'Zahlmethoden-Titel, der dem Kunden in der Bezahlstrecke angezeigt werden soll.',
                PAYDIREKT_CLASS => 'paydirekt-title',
                PAYDIREKT_DESC_TIP => true,
            ),
            PAYDIREKT_PARAMETER_PAYMENT_HTML => array(
                PAYDIREKT_TITLE => __('Beschreibungstext', PAYDIREKT_PAYMENT_ID),
                PAYDIREKT_TYPE => PAYDIREKT_TEXTAREA,
                PAYDIREKT_DEFAULT => PAYDIREKT_PAYMENT_DESCRIPTION,
                PAYDIREKT_DESCRIPTION => 'Beschreibungstext, der dem Kunden in der Bezahlstrecke angezeigt werden soll.',
                PAYDIREKT_CLASS => 'paydirekt-description',
                PAYDIREKT_DESC_TIP => true,
            ),
            PAYDIREKT_PARAMETER_APIKEY => array(
                PAYDIREKT_TITLE => __('API-Key', PAYDIREKT_PAYMENT_ID),
                PAYDIREKT_TYPE => PAYDIREKT_TEXT,
                PAYDIREKT_DESCRIPTION => 'Der API-Key identifiziert jeden Shop eindeutig. '
                . 'Der API-Key muss im paydirekt Händlerportal erstellt werden. '
                . 'API-Keys beginnend mit 00000000- sprechen automatisch das Testsystem an. Andernfalls wird das Produktionssystem angesprochen.',
                PAYDIREKT_CLASS => 'paydirekt-api-key paydirekt-validate-field',
                PAYDIREKT_DESC_TIP => true,
            ),
            PAYDIREKT_PARAMETER_APISECRET => array(
                PAYDIREKT_TITLE => __('API-Secret', PAYDIREKT_PAYMENT_ID),
                PAYDIREKT_TYPE => PAYDIREKT_PASSWORD,
                PAYDIREKT_DESCRIPTION => 'Das API-Secret dient als Passwort und wird im '
                . 'paydirekt Händlerportal bei Erstellung eines API-Keys einmalig angezeigt.',
                PAYDIREKT_CLASS => 'paydirekt-api-secret paydirekt-validate-field',
                PAYDIREKT_DESC_TIP => true,
            ),
            PAYDIREKT_PARAMETER_ORDERNOTE => array(
                PAYDIREKT_TITLE => __('Freitext (Käufer VWZ)', PAYDIREKT_PAYMENT_ID),
                PAYDIREKT_TYPE => PAYDIREKT_TEXT,
                PAYDIREKT_DESCRIPTION => 'Freitextfeld, das im Kontoauszug (Verwendungszweck) '
                . 'des Käufers angezeigt wird. (Nur SEPA-konforme Zeichen, max. 37 Zeichen). '
                . 'Es können die folgenden Variablen genutzt werden, die durch die entsprechenden Werte automatisch ersetzt werden: '
                . '{{Bestellnummer}} {{Kundennummer}} {{Vorname}} {{Name}} {{Bestelldatum}}',
                PAYDIREKT_CLASS => 'paydirekt-order-note paydirekt-validate-field',
                PAYDIREKT_DESC_TIP => true,
            ),
            PAYDIREKT_PARAMETER_MINIMUMAGE => array(
                PAYDIREKT_TITLE => __('Mindestalter', PAYDIREKT_PAYMENT_ID),
                PAYDIREKT_TYPE => PAYDIREKT_TEXT,
                PAYDIREKT_DEFAULT => '0',
                PAYDIREKT_DESCRIPTION => 'Das Mindestalter (in Jahren), das der Käufer erreicht haben muss, um die Bestellung ausführen zu dürfen. '
                . 'Wird paydirekt seitig nach Login des Käufers geprüft. Bei Unterschreiten des Alters wird die Zahlung abgebrochen. '
                . 'Bei leerem Feld erfolgt keine Altersverifikation.(Minimal 1 Jahr, maximal 99 Jahre)',
                PAYDIREKT_CLASS => 'paydirekt-minimum-age paydirekt-validate-field',
                PAYDIREKT_DESC_TIP => true,
            ),
            PAYDIREKT_PARAMETER_CHOOSECHECKOUT => array(
                PAYDIREKT_TITLE => __('Buchungstyp', PAYDIREKT_PAYMENT_ID),
                PAYDIREKT_TYPE => PAYDIREKT_SELECT,
                PAYDIREKT_DEFAULT => PAYDIREKT_CHECKOUT_TYPE_DIRECT_SALE,
                PAYDIREKT_DESCRIPTION => 'Der Buchungstyp gibt den Checkout-Typ bei paydirekt an: '
                . 'Einmalzahlung (Directsale) = Die Zahlung erfolgt sofort. '
                . 'Vorbestellung (Order) = Die Zahlung wird vorgemerkt und muss später manuell '
                . 'vom Händler (bei Warenlieferung) gebucht werden (Capture). '
                . 'Gesicherte Vorbestellung (Order secured) = Die Zahlung wird vorgemerkt und muss später manuell vom Händler '
                . '(bei Warenlieferung) gebucht werden (Capture). Für eine gesicherte Vorbestellung wird eine Zahlungsgarantie '
                . 'für den gewählten Zeitraum (maximal 15 Kalendertage) an den Händler ausgesprochen.',
                'options' => array(
                    PAYDIREKT_CHECKOUT_TYPE_DIRECT_SALE => 'Einmalzahlung (Directsale)',
                    PAYDIREKT_CHECKOUT_TYPE_ORDER => 'Vorbestellung (Order)',
                    PAYDIREKT_CHECKOUT_TYPE_ORDER_SECURED => 'gesicherte Vorbestellung (Order)',
                ),
                PAYDIREKT_CLASS => 'paydirekt-choose-checkout',
                PAYDIREKT_DESC_TIP => true,
            ),
            PAYDIREKT_PARAMETER_MINIMUMAMOUNT => array(
                PAYDIREKT_TITLE => __('minamount', PAYDIREKT_PAYMENT_ID),
                PAYDIREKT_TYPE => PAYDIREKT_TEXT,
                'std' => '0,01', // WooCommerce < 2.0
                PAYDIREKT_DEFAULT => '0,01', // WooCommerce >= 2.0
                PAYDIREKT_DESCRIPTION => 'Warenkorbsumme die mindestens erreicht werden muss, '
                . 'damit paydirekt als Zahlungsvariante angezeigt wird. '
                . 'paydirekt erfordert einen Mindestzahlbetrag von 0,01. (Währung ist EUR)',
                PAYDIREKT_CLASS => 'paydirekt-minimumamount paydirekt-validate-field',
                PAYDIREKT_DESC_TIP => true,
            ),
            PAYDIREKT_PARAMETER_MAXIMUMAMOUNT => array(
                PAYDIREKT_TITLE => __('maxamount', PAYDIREKT_PAYMENT_ID),
                PAYDIREKT_TYPE => PAYDIREKT_TEXT,
                'std' => '50000,00', // WooCommerce < 2.0
                PAYDIREKT_DEFAULT => '50000,00', // WooCommerce >= 2.0
                PAYDIREKT_DESCRIPTION => 'Warekorbsumme die nicht überschritten werden darf, '
                . 'damit paydirekt als Zahlungsvariante angezeigt wird. '
                . 'paydirekt erlaubt einen Maximalbetrag von 50000,00. (Währung ist EUR)',
                PAYDIREKT_CLASS => 'paydirekt-maximumamount paydirekt-validate-field',
                PAYDIREKT_DESC_TIP => true,
            ),
            PAYDIREKT_PARAMETER_LOGLEVEL => array(
                PAYDIREKT_TITLE => __('Log-Level', PAYDIREKT_PAYMENT_ID),
                PAYDIREKT_TYPE => PAYDIREKT_SELECT,
                PAYDIREKT_DEFAULT => PAYDIREKT_LOG_LEVEL_ERROR,
                PAYDIREKT_DESCRIPTION => 'Der Log-Level schreibt wichtige zahlungsrelevante Ereignisse in die Log-Datei des Shop-Systems. '
                . 'Es wird empfohlen den Status ERROR zu belassen. Dieser schreibt sämtliche Fehler in die Log-Datei. '
                . 'Andere Einstellungen dienen vor allem der Fehleranalyse und sollten nur auf  Anraten des Supports genutzt werden.',
                'options' => array(
                    PAYDIREKT_LOG_LEVEL_DEAKTIVIERT => PAYDIREKT_LOG_LEVEL_DEAKTIVIERT,
                    PAYDIREKT_LOG_LEVEL_DEBUG => PAYDIREKT_LOG_LEVEL_DEBUG,
                    PAYDIREKT_LOG_LEVEL_INFO => PAYDIREKT_LOG_LEVEL_INFO,
                    PAYDIREKT_LOG_LEVEL_ERROR => PAYDIREKT_LOG_LEVEL_ERROR,
                ),
                PAYDIREKT_CLASS => 'paydirekt-log-level',
                PAYDIREKT_DESC_TIP => true,
            ),
            PAYDIREKT_PARAMETER_MERCHANT_RECONCILATION_REFERENCE_NUMBER => array(
                PAYDIREKT_TITLE => __('Referenz-Nummer', PAYDIREKT_PAYMENT_ID),
                PAYDIREKT_TYPE => PAYDIREKT_TEXT,
                PAYDIREKT_DESCRIPTION => 'Händler-interne Referenznummer, die anschließend in den paydirekt '
                . 'Reporten zur Transaktion zur Verfügung steht.'
                . '(Max. 30 Zeichen) Es können die folgenden Variablen genutzt werden, die durch die '
                . 'entsprechenden Werte automatisch ersetzt werden:'
                . ' {{Bestellnummer}} {{Kundennummer}} {{Vorname}} {{Name}} {{Bestelldatum}}',
                PAYDIREKT_CLASS => 'paydirekt-merchant-reconciliation-reference-number paydirekt-validate-field',
                PAYDIREKT_DESC_TIP => true,
            ),
            PAYDIREKT_PARAMETER_RECONCILIATIONNUMBER => array(
                PAYDIREKT_TITLE => __('Reconciliation-Nummer', PAYDIREKT_PAYMENT_ID),
                PAYDIREKT_TYPE => PAYDIREKT_TEXT,
                PAYDIREKT_DESCRIPTION => 'Händler-interne Reconciliationnummer, die im Händler-Kontoauszug im Verwendungszweck angezeigt wird.'
                . ' (Nur SEPA-konforme Zeichen, max. 30 Zeichen) Es können die folgenden Variablen genutzt werden, die durch die entsprechenden'
                . ' Werte automatisch ersetzt werden: {{Bestellnummer}} {{Kundennummer}} {{Vorname}} {{Name}} {{Bestelldatum}}',
                PAYDIREKT_CLASS => 'paydirekt-merchant-reconciliation-number paydirekt-validate-field',
                PAYDIREKT_DESC_TIP => true,
            ),
            PAYDIREKT_CHECKCONFIG_BUTTON => array(
                PAYDIREKT_TYPE => PAYDIREKT_BUTTON,
                PAYDIREKT_CLASS => 'paydirekt-check-config',
            ),
        );
    }

    public static function getAjaxData()
    {
        $logger = PaydirektLogger::getInstance("PaydirektConfigForm");
        $apiKey = ($_POST[PAYDIREKT_PARAMETER_APIKEY]);
        $apiSecret = ($_POST[PAYDIREKT_PARAMETER_APISECRET]);
        $logger->info("Configuration saved");
        $liveSystem = Utils::isLiveSystem($apiKey);

        Token::getToken($apiSecret, $apiKey, $liveSystem);

        if (empty(Token::getError())) {
            $response = array(
                'what' => 'check-config',
                'action' => 'paydirekt_check_config',
                'id' => '1',
                'data' => 'true',
            );
        } else {
            $response = array(
                'what' => 'check-config',
                'action' => 'paydirekt_check_config',
                'id' => '0',
                'data' => 'false',
            );
        }
        $xmlResponse = new \WP_Ajax_Response($response);
        $xmlResponse->send();
        wp_die();
    }

}
