<?php
/**
 * @category    Payment Plugin
 * @package     paydirekt
 * @author      Logata Digital Solutions GmbH
 * @copyright   Logata Digital Solutions GmbH
 * @license     https://logata.com/paydirekt-lizenzbedingungen
 * @version     1.0.44
 * @link        https://www.paydirekt.de
 */

namespace Bitergo\PaydirektWooCommerce\classes;

use Bitergo\PaydirektWooCommerce\Lib\PaydirektLogger;
use Bitergo\PaydirektWooCommerce\classes\components\PaydirektOrderdetailTable;
use Bitergo\PaydirektWooCommerce\classes\components\PaydirektOrderDetailPanel;
use Bitergo\PaydirektWooCommerce\classes\components\PaydirektActionButtons;
use Bitergo\PaydirektWooCommerce\classes\PaydirektUtils;
use Bitergo\PaydirektWooCommerce\Lib\Utils;
use Bitergo\PaydirektWooCommerce\Lib\Checkout;
use Bitergo\PaydirektWooCommerce\Lib\Token;
use Bitergo\PaydirektWooCommerce\Lib\Refund;
use Bitergo\PaydirektWooCommerce\Lib\Capture;

if (!defined('ABSPATH')) {
    exit;
}
class PaydirektOrderView
{

    private $logger;

    public function __construct()
    {
        global $woocommerce;

        $this->logger = PaydirektLogger::getInstance(get_class($this));
        $overview_url = wp_nonce_url(admin_url('edit.php?post_type=shop_order'));
        $backButton = "<div class='wrap'><a href='" . $overview_url . "' class='button button-primary'>" 
        . __("back to orders", PAYDIREKT_PAYMENT_ID) . "</a></div>";

        wp_register_style('jquery-ui', plugin_dir_url(dirname(__FILE__)) . "resources/css/jquery-ui.css");
        wp_enqueue_style('jquery-ui');
        wp_enqueue_style('fontawesome',
            plugins_url('../resources/css/font-awesome.min.css', __FILE__)
        );
        wp_enqueue_style('footable',
            plugins_url('../resources/css/footable.standalone.min.css', __FILE__)
        );
        wp_enqueue_style('jquery-growl',
            plugins_url('../resources/css/jquery.growl.css', __FILE__)
        );
        
        wp_enqueue_script('jquery-growl',
            plugins_url('../resources/js/jquery.growl.js', __FILE__),
            array(PAYDIREKT_JQUERY),
            null,
            true
        );
        wp_enqueue_script('jquery-ui-core');
        wp_enqueue_script('jquery-ui-datepicker');
        wp_enqueue_script('paydirekt-footable',
            plugins_url('../resources/js/footable.min.js', __FILE__),
            array(PAYDIREKT_JQUERY),
            null,
            true);
        wp_enqueue_script('paydirekt-utils',
            plugins_url('../resources/js/paydirekt-utils.js', __FILE__),
            array(PAYDIREKT_JQUERY),
            null,
            true);
        wp_enqueue_script('order-overview',
            plugins_url('../resources/js/paydirekt-order-overview.js', __FILE__),
            array(PAYDIREKT_JQUERY),
            null,
            true);

        if (!isset($_GET['order_id'])) {
            $message = __("Bestellnummer nicht gefunden.", 'fulino-paydirekt');
            PaydirektUtils::alert(PAYDIREKT_ERROR, $message);
            echo wp_kses($backButton, wp_kses_allowed_html('post'));
            return;
        }
        $orderId = wc_sanitize_order_id($_GET['order_id']);
        $order = new \WC_Order($orderId);
        $checkout = json_decode(static::getCheckoutById($order->get_transaction_id()), true);
        if (isset($checkout[PAYDIREKT_MESSAGES])) {
            $messages = $checkout[PAYDIREKT_MESSAGES];
            foreach ($messages as $message) {
                $errorMessage = __("Checkout nicht gefunden. (" . $message['code'] . ")", 'fulino-paydirekt');
                PaydirektUtils::alert(PAYDIREKT_ERROR, $errorMessage);
                echo wp_kses($backButton, wp_kses_allowed_html('post'));

                return;
            }
        }
        if (isset($_POST['saveCapture'])) {
            $this->saveCapture($order);
        }
        if (isset($_POST['saveRefund'])) {
            $this->saveRefund($order);
        }
        if (isset($_GET[PAYDIREKT_ACTION]) && sanitize_text_field($_GET[PAYDIREKT_ACTION]) == 'close-order') {
            $this->closeOrder($order);
        }

        $paydirektOrderdetailTable = new PaydirektOrderdetailTable();
        $paydirektOrderdetailTable->prepare_items();
        $paydirektOrderdetailTable->render();

        $paydirektCheckoutData = $paydirektOrderdetailTable->getData();
        $paydirektOrderdetailPanel = new PaydirektOrderDetailPanel($paydirektCheckoutData);
        $paydirektOrderdetailPanel->prepare_items();
        $paydirektOrderdetailPanel->render();

        $paydirektActionButtons = new PaydirektActionButtons($paydirektCheckoutData);
        $paydirektActionButtons->prepare_items();
        $paydirektActionButtons->render();
    }

    public static function getAjaxData()
    {
        $type = sanitize_text_field($_POST[PAYDIREKT_TYPE]);
        $transactionId = sanitize_text_field($_POST[PAYDIREKT_TRANSACTIONID]);
        $checkoutId = sanitize_text_field($_POST[PAYDIREKT_CHECKOUT_ID]);

        switch ($type) {
            case "CAPTURE_DIRECT_SALE":
            case "CAPTURE_ORDER":
                $paydirektItemData = static::getCaptureById($transactionId, $checkoutId);
                break;
            case "REFUND":
                $paydirektItemData = static::getRefundById($transactionId, $checkoutId);
                break;
            case "ORDER":
            case "DIRECT_SALE":
            case "ORDER_SECURED":
            default:
                $paydirektItemData = static::getCheckoutById($transactionId);
                break;
        }

        $paydirektItemData = json_decode($paydirektItemData, true);
        $paydirektOrderdetailPanel = new PaydirektOrderDetailPanel(array($paydirektItemData), $transactionId);
        $paydirektOrderdetailPanel->prepare_items();
        $paydirektOrderdetailPanel->render();

        wp_die();
    }

    public static function getCheckoutById($checkoutId)
    {
        $settings = get_option(PAYDIREKT_WOOCOMMERCE_PAYDIREKT_SETTINGS);
        $apiKey = $settings[PAYDIREKT_PARAMETER_APIKEY];
        $apiSecret = $settings[PAYDIREKT_PARAMETER_APISECRET];
        $liveSystem = Utils::isLiveSystem($apiKey);

        try {
            $token = Token::getToken($apiSecret, $apiKey, $liveSystem);
            $checkout = Checkout::retrieveCheckout($token, $checkoutId, $liveSystem);

            return $checkout[PAYDIREKT_RESPONSE];
        } catch (\Exception $ex) {
            return "Error! " . $ex->getMessage();
        }
    }

    public static function getCaptureById($transactionId, $checkoutId)
    {
        $settings = get_option(PAYDIREKT_WOOCOMMERCE_PAYDIREKT_SETTINGS);
        $apiKey = $settings[PAYDIREKT_PARAMETER_APIKEY];
        $apiSecret = $settings[PAYDIREKT_PARAMETER_APISECRET];
        $liveSystem = Utils::isLiveSystem($apiKey);
        try {
            $token = Token::getToken($apiSecret, $apiKey, $liveSystem);
            $capture = Capture::retrieveCapture($token, $checkoutId, $transactionId, $liveSystem);

            return $capture[PAYDIREKT_RESPONSE];
        } catch (\Exception $ex) {
            return "Error " . $ex->getMessage();
        }
    }

    public function getRefundById($transactionId, $checkoutId)
    {
        $settings = get_option(PAYDIREKT_WOOCOMMERCE_PAYDIREKT_SETTINGS);
        $apiKey = $settings[PAYDIREKT_PARAMETER_APIKEY];
        $apiSecret = $settings[PAYDIREKT_PARAMETER_APISECRET];
        $liveSystem = Utils::isLiveSystem($apiKey);
        try {
            $token = Token::getToken($apiSecret, $apiKey, $liveSystem);
            $refund = Refund::retrieveRefund($token, $checkoutId, $transactionId, $liveSystem);
            return $refund[PAYDIREKT_RESPONSE];
        } catch (\Exception $ex) {
            return "Error" . $ex->getMessage();
        }
    }

    public function saveCapture($order)
    {
        $amount = sanitize_text_field($_POST[PAYDIREKT_AMOUNT]);
        $finalCapture = sanitize_text_field($_POST[PAYDIREKT_FINAL_CAPTURE]) == "on" ? true : false;
        $merchantCaptureReferenceNumber = Checkout::getValidSepaString(sanitize_text_field($_POST[PAYDIREKT_MERCHANT_CAPTURE_REFERENCE_NUMBER]));
        $merchantReconciliationReferenceNumber = Checkout::getValidSepaString(sanitize_text_field($_POST[PAYDIREKT_MERCHANT_RECONCILATION_REFERENCE_NUMBER]));
        $captureInvoiceReferenceNumber = Checkout::getValidSepaString(sanitize_text_field($_POST[PAYDIREKT_CAPTURE_INVOICE_REFERENCE_NUMBER]));
        $note = Checkout::getValidSepaStringNote(sanitize_text_field($_POST['note']));
        $transactionId = $order->get_transaction_id();

        $payloadCapture = array();
        $payloadCapture = [
            PAYDIREKT_AMOUNT => str_replace(',', '.', $amount),
            PAYDIREKT_FINAL_CAPTURE => $finalCapture,
            PAYDIREKT_NOTE => $note,
            PAYDIREKT_MERCHANT_CAPTURE_REFERENCE_NUMBER => $merchantCaptureReferenceNumber,
            PAYDIREKT_MERCHANT_RECONCILATION_REFERENCE_NUMBER => $merchantReconciliationReferenceNumber,
            PAYDIREKT_CAPTURE_INVOICE_REFERENCE_NUMBER => $captureInvoiceReferenceNumber,
            PAYDIREKT_CALLBACKURL_UPDATES => '',
            PAYDIREKT_DELIVERY_INFORMATION => array(
                PAYDIREKT_DELIVERY_INFORMATION . '.' . PAYDIREKT_EXPECTED_SHIPPING_DATE => '',
                PAYDIREKT_DELIVERY_INFORMATION . '.' . PAYDIREKT_LOGISTICS_PROVIDER => '',
                PAYDIREKT_DELIVERY_INFORMATION . '.' . PAYDIREKT_TRACKNG_NUMBER => ''),
        ];

        $settings = get_option(PAYDIREKT_WOOCOMMERCE_PAYDIREKT_SETTINGS);
        $apiKey = $settings[PAYDIREKT_PARAMETER_APIKEY];
        $apiSecret = $settings[PAYDIREKT_PARAMETER_APISECRET];
        $liveSystem = Utils::isLiveSystem($apiKey);

        try {
            $token = Token::getToken($apiSecret, $apiKey, $liveSystem);
        } catch (\Exception $ex) {
            return "Error." . $ex->getMessage();
        }
        if (Token::getError()) {
            $this->logger->error("saveCapture: generate token failed: ", array("Token status array:" => Token::getError()));
        }

        // fire the capture request
        $captureRequest = Capture::createCapture($token, $transactionId, $payloadCapture, $liveSystem);

        $statusCode = Utils::resolveStatus(Capture::STATUS, $captureRequest);
        $this->logger->debug("captureAction: capture request message: ", $statusCode[PAYDIREKT_MESSAGE]);

        if ($statusCode[PAYDIREKT_MESSAGE] == "OK") {
            $this->logger->info("capture created successfully");
            PaydirektUtils::alert("success", $statusCode[PAYDIREKT_DESCRIPTION]);

            if ($finalCapture) {
                // finish order payment
                $order->payment_complete();
                $this->logger->debug("captureAction: capture created with status 'final capture'");
            }
        } else {
            $message = $statusCode[PAYDIREKT_DESCRIPTION] . " (" . $statusCode[PAYDIREKT_MESSAGE] . ")";
            PaydirektUtils::alert("error", $message);
        }
    }

    public function saveRefund($order)
    {
        $amount = sanitize_text_field($_POST[PAYDIREKT_AMOUNT]);
        $reason = sanitize_text_field($_POST[PAYDIREKT_REASON]);
        $merchantRefundReferenceNumber = Checkout::getValidSepaString(sanitize_text_field($_POST[PAYDIREKT_MERCHANT_REFUND_REFERENCE_NUMBER]));
        $merchantReconciliationReferenceNumber = Checkout::getValidSepaString(sanitize_text_field($_POST[PAYDIREKT_MERCHANT_RECONCILATION_REFERENCE_NUMBER]));
        $note = Checkout::getValidSepaStringNote(sanitize_text_field($_POST[PAYDIREKT_NOTE]));

        $transactionId = $order->get_transaction_id();

        $settings = get_option(PAYDIREKT_WOOCOMMERCE_PAYDIREKT_SETTINGS);
        $apiKey = $settings[PAYDIREKT_PARAMETER_APIKEY];
        $apiSecret = $settings[PAYDIREKT_PARAMETER_APISECRET];
        $liveSystem = Utils::isLiveSystem($apiKey);

        try {
            $token = Token::getToken($apiSecret, $apiKey, $liveSystem);
        } catch (\Exception $ex) {
            return "Error!" . $ex->getMessage();
        }
        if (Token::getError()) {
            $this->logger->error("saveRefund: generate token failed: ", array("Token status array" => Token::getError()));
        }

        $payloadRefund = array();
        $payloadRefund = [
            PAYDIREKT_AMOUNT => str_replace(',', '.', $amount),
            PAYDIREKT_REASON => $reason,
            PAYDIREKT_NOTE => $note,
            PAYDIREKT_MERCHANT_REFUND_REFERENCE_NUMBER => $merchantRefundReferenceNumber,
            PAYDIREKT_MERCHANT_RECONCILATION_REFERENCE_NUMBER => $merchantReconciliationReferenceNumber,
            PAYDIREKT_CALLBACKURL_UPDATES => '',
            PAYDIREKT_DELIVERY_INFORMATION => array(
                PAYDIREKT_DELIVERY_INFORMATION . '.' . PAYDIREKT_EXPECTED_SHIPPING_DATE => '',
                PAYDIREKT_DELIVERY_INFORMATION . '.' . PAYDIREKT_LOGISTICS_PROVIDER => '',
                PAYDIREKT_DELIVERY_INFORMATION . '.' . PAYDIREKT_TRACKNG_NUMBER => ''),
        ];
        // fire the capture request
        $refundRequest = Refund::createRefund($token, $transactionId, $payloadRefund, $liveSystem);
        $statusCode = Utils::resolveStatus(Refund::STATUS, $refundRequest);
        $this->logger->debug("refundAction: refund request message: ", $statusCode[PAYDIREKT_MESSAGE]);

        if ($statusCode[PAYDIREKT_MESSAGE] != "OK") {
            $message = $statusCode[PAYDIREKT_DESCRIPTION] . " (" . $statusCode[PAYDIREKT_MESSAGE] . ")";
            PaydirektUtils::alert(PAYDIREKT_ERROR, $message);
            $this->logger->error("refundAction: error creating refund. reason: ", $statusCode);
        } else {
            PaydirektUtils::alert("success", $statusCode[PAYDIREKT_DESCRIPTION]);
            $this->logger->info("refund created successfully");
        }
        $this->logger->debug("refundAction end");
    }

    public function closeOrder($order)
    {
        $this->logger->debug("closeOrder start");

        $transactionId = $order->get_transaction_id();

        $settings = get_option(PAYDIREKT_WOOCOMMERCE_PAYDIREKT_SETTINGS);
        $apiKey = $settings[PAYDIREKT_PARAMETER_APIKEY];
        $apiSecret = $settings[PAYDIREKT_PARAMETER_APISECRET];
        $liveSystem = Utils::isLiveSystem($apiKey);

        try {
            $token = Token::getToken($apiSecret, $apiKey, $liveSystem);
        } catch (\Exception $ex) {
            return "Error!" . $ex->getMessage();
        }
        if (Token::getError()) {
            $this->logger->error("saveRefund: generate token failed: ", array("Token status array" => Token::getError()));
        }

        $this->logger->debug("start close order");
        $orderCloseResponse = Capture::closeOrder($token, $transactionId, $liveSystem);
        $this->logger->debug("order closed:", $orderCloseResponse);

        $statusCode = Utils::resolveStatus(Capture::STATUS, $orderCloseResponse);
        $this->logger->debug("closeOrder: capture request status: ", $statusCode);
        $this->logger->debug("closeOrder: capture request message: ", $statusCode[PAYDIREKT_MESSAGE]);

        // the closeOrder api call response has no status, so check if the response has a checkout and check if this checkout is closed.
        if ($statusCode[PAYDIREKT_MESSAGE] == null) {
            $responseArray = json_decode($orderCloseResponse[PAYDIREKT_RESPONSE], true);
            if ($responseArray && $responseArray[PAYDIREKT_STATUS] == "CLOSED") {
                $statusCode[PAYDIREKT_MESSAGE] = "OK";
            }
        }

        if ($statusCode[PAYDIREKT_MESSAGE] == "OK") {
            $this->logger->info("order successfully closed");
            $this->logger->debug("closeOrder: order status set to 'paid'");
            $returnValue = $statusCode[PAYDIREKT_MESSAGE];
            // update order status
            $order->payment_complete();
        } else {
            $this->logger->error("closeOrder: error closing order. reason: ", $statusCode);
            $returnValue = $statusCode[PAYDIREKT_DESCRIPTION] . " (" . $statusCode[PAYDIREKT_MESSAGE] . ")";
        }
        $this->logger->debug("closeOrderAction: returned status: ", $returnValue);
        $this->logger->debug("closeOrderAction end");

        return $returnValue;
    }
}
