<?php
/**
 * @category    Payment Plugin
 * @package     paydirekt
 * @author      Logata Digital Solutions GmbH
 * @copyright   Logata Digital Solutions GmbH
 * @license     https://logata.com/paydirekt-lizenzbedingungen
 * @version     1.0.44
 * @link        https://www.paydirekt.de
 */

namespace Bitergo\PaydirektWooCommerce\classes;

use Bitergo\PaydirektWooCommerce\Lib\PaydirektLogger;
use Bitergo\PaydirektWooCommerce\classes\PaydirektUtils;

if (!defined('ABSPATH')) {
    exit;
}
class PaydirektRefund
{

    private $orderId;
    private $logger;
    private $settings;

    public function __construct()
    {
        $this->logger = PaydirektLogger::getInstance(get_class($this));

        wp_enqueue_script('paydirekt-utils', plugins_url('../resources/js/paydirekt-utils.js', __FILE__), array('jquery'), null, true);
        wp_enqueue_script('paydirekt-refund', plugins_url('../resources/js/paydirekt-refund.js', __FILE__), array('jquery'), null, true);

        $this->orderId = wc_sanitize_order_id($_GET['order_id']);
        $order = new \WC_Order($this->orderId);
        $this->settings = PaydirektUtils::getSettings($order);
        $this->render();
    }

    public function render()
    {
        $saveUrl = wp_nonce_url(admin_url('admin.php?page=paydirekt-orderview&order_id=' . $this->orderId), 'paydirekt-overview');
        $cancelUrl = wp_nonce_url(admin_url('admin.php?page=paydirekt-orderview&order_id=' . $this->orderId), 'paydirekt-overview');
        $reason = array(
            "CUSTOMER_RETURN_GOODS" => __("CUSTOMER_RETURN_GOODS", PAYDIREKT_PAYMENT_ID),
            "REFUND_OBLIGINGNESS" => __("REFUND_OBLIGINGNESS", PAYDIREKT_PAYMENT_ID),
            "MERCHANT_CAN_NOT_DELIVER_GOODS" => __("MERCHANT_CAN_NOT_DELIVER_GOODS", PAYDIREKT_PAYMENT_ID),
            "MERCHANT_TECHNICAL_PROBLEM" => __("MERCHANT_TECHNICAL_PROBLEM", PAYDIREKT_PAYMENT_ID));
        ?>
        <div class='wrap woocommerce'>
            <form action="<?php echo $saveUrl?>" method="post">
                <table class="form-table paydirekt-form">
                    <tbody>
                        <?php echo PaydirektUtils::createFormElementRow(PAYDIREKT_TEXT,
                            __(PAYDIREKT_AMOUNT, PAYDIREKT_PAYMENT_ID),
                            PAYDIREKT_AMOUNT,
                            __("refund_amount_help", PAYDIREKT_PAYMENT_ID)
                        )?>
                        <?php echo PaydirektUtils::createFormElementRow(PAYDIREKT_SELECT,
                            __(PAYDIREKT_REASON, PAYDIREKT_PAYMENT_ID),
                            PAYDIREKT_REASON,
                            __("refund_reason_help", PAYDIREKT_PAYMENT_ID),
                            $reason
                        )?>
                        <?php echo PaydirektUtils::createFormElementRow(PAYDIREKT_TEXT,
                            __(PAYDIREKT_MERCHANT_REFUND_REFERENCE_NUMBER, PAYDIREKT_PAYMENT_ID),
                            PAYDIREKT_MERCHANT_REFUND_REFERENCE_NUMBER,
                            __("refund_merchantRefundReferenceNumber_help", PAYDIREKT_PAYMENT_ID),
                            $this->settings[PAYDIREKT_PARAMETER_MERCHANT_RECONCILATION_REFERENCE_NUMBER]
                        )?>
                        <?php echo PaydirektUtils::createFormElementRow(PAYDIREKT_TEXT,
                            __(PAYDIREKT_PARAMETER_MERCHANT_RECONCILATION_REFERENCE_NUMBER, PAYDIREKT_PAYMENT_ID),
                            PAYDIREKT_PARAMETER_MERCHANT_RECONCILATION_REFERENCE_NUMBER,
                            __("refund_merchantreconciliationreferencenumber_help", PAYDIREKT_PAYMENT_ID),
                            $this->settings[PAYDIREKT_PARAMETER_RECONCILIATIONNUMBER]
                        )?>
                        <?php echo PaydirektUtils::createFormElementRow(PAYDIREKT_TEXT,
                            __(PAYDIREKT_NOTE, PAYDIREKT_PAYMENT_ID),
                            PAYDIREKT_NOTE,
                            __("note_help", PAYDIREKT_PAYMENT_ID),
                            $this->settings[PAYDIREKT_PARAMETER_ORDERNOTE]
                        )?>
                    </tbody>
                </table>
                <div class="buttons">
                    <?php echo PaydirektUtils::createButtonElement($cancelUrl,
                        "button paydirekt-cancel-button",
                        __("cancel", PAYDIREKT_PAYMENT_ID),
                        "cancelRefund"
                    )?>
                    <?php echo PaydirektUtils::createFormElement("submit",
                        "saveRefund",
                        "button-primary paydirekt-save-button",
                        __("refund_save", PAYDIREKT_PAYMENT_ID)
                    )?>
                </div>
            </form>
        </div>
        <?php
}
}