<?php
/**
 * @category    Payment Plugin
 * @package     paydirekt
 * @author      Logata Digital Solutions GmbH
 * @copyright   Logata Digital Solutions GmbH
 * @license     https://logata.com/paydirekt-lizenzbedingungen
 * @version     1.0.44
 * @link        https://www.paydirekt.de
 */

namespace Bitergo\PaydirektWooCommerce\classes;

use Bitergo\PaydirektWooCommerce\classes\ResponseStatusEnum;
use Bitergo\PaydirektWooCommerce\classes\PaydirektUtils;

if (!defined('ABSPATH')) {
    exit;
}
class PaydirektReturnAction
{
    public function __construct()
    {
    }

    /**
     * Callback function for payment return
     *
     * @return void
     */
    public function check_response()
    {
        global $woocommerce;
        global $wp_rewrite;

        if (isset($_GET['woopaydirekt'])) {

            $status = sanitize_text_field($_GET[PAYDIREKT_STATUS]);
            $order_id = wc_sanitize_order_id($_GET['order_id']);
            $redirect_url = array();

            if ($order_id == 0 || $order_id == '') {
                return;
            }

            $order = new \WC_Order($order_id);

            if ($order->has_status('completed') || $order->has_status('processing')) {
                return;
            }

            switch ($status) {
                case ResponseStatusEnum::ACCEPTED:
                    if (PaydirektUtils::getConfig(PAYDIREKT_PARAMETER_CHOOSECHECKOUT) == PAYDIREKT_CHECKOUT_TYPE_DIRECT_SALE) {
                        $order->payment_complete();
                    }
                    if (PaydirektUtils::getConfig(PAYDIREKT_PARAMETER_CHOOSECHECKOUT) == PAYDIREKT_CHECKOUT_TYPE_ORDER
                        || PaydirektUtils::getConfig(PAYDIREKT_PARAMETER_CHOOSECHECKOUT) == PAYDIREKT_CHECKOUT_TYPE_ORDER_SECURED) {
                        $order->update_status('on-hold',
                            sprintf(__('%s payment type ORDER, status on hold! Transaction ID: %d', PAYDIREKT_WOOCOMMERCE),
                                PAYDIREKT_PAYMENT_ID,
                                $order->get_transaction_id())
                        );
                        do_action('woocommerce_payment_complete', PAYDIREKT_COMPATIBILITY ? $order->id : $order->get_id());
                    }
                    $order->add_order_note(sprintf(__('%s payment approved! Transaction ID: %s',
                        PAYDIREKT_WOOCOMMERCE),
                        PAYDIREKT_PAYMENT_ID,
                        $order->get_transaction_id())
                    );

                    break;
                case ResponseStatusEnum::REJECT:
                    $order->update_status('cancelled');
                    $order->delete();
                    $redirect_url = array(PAYDIREKT_RESULT => ResponseStatusEnum::REJECT, PAYDIREKT_REDIRECT => add_query_arg("rc", "true", \wc_get_cart_url()));
                    break;
                case ResponseStatusEnum::CANCEL:
                    $order->update_status('cancelled');
                    $order->delete();
                    $redirect_url = array(PAYDIREKT_RESULT => ResponseStatusEnum::CANCEL, PAYDIREKT_REDIRECT => add_query_arg("rc", "true", \wc_get_cart_url()));
                    break;
                case ResponseStatusEnum::AGE:
                    $order->update_status('cancelled');
                    $order->delete();
                    $redirect_url = array(PAYDIREKT_RESULT => ResponseStatusEnum::AGE, PAYDIREKT_REDIRECT => add_query_arg("rc", "true", \wc_get_cart_url()));
                    break;
                default:
                    break;
            }
            return $redirect_url;
            /** end new version */
        }
    }
}
