<?php
/**
 * @category    Payment Plugin
 * @package     paydirekt
 * @author      Logata Digital Solutions GmbH
 * @copyright   Logata Digital Solutions GmbH
 * @license     https://logata.com/paydirekt-lizenzbedingungen
 * @version     1.0.44
 * @link        https://www.paydirekt.de
 */

namespace Bitergo\PaydirektWooCommerce\classes;

if (!defined('ABSPATH')) {
    exit;
}

use Bitergo\PaydirektWooCommerce\classes\components\PaydirektTable;
use Bitergo\PaydirektWooCommerce\classes\PaydirektUtils;
use Bitergo\PaydirektWooCommerce\Lib\PaydirektLogger;

class PaydirektTransactionList extends PaydirektTable
{
    private $logger;
    private $tableData;

    public function __construct()
    {
        $logLevel = PaydirektUtils::getConfig(PAYDIREKT_PARAMETER_LOGLEVEL);
        $this->logger = PaydirektLogger::getInstance(get_class($this), $logLevel);

        wp_register_style('jquery-ui', plugin_dir_url(dirname(__FILE__)) . "resources/css/jquery-ui.css");
        wp_enqueue_style('jquery-ui');
        wp_enqueue_style('fontawesome',
            plugins_url('../resources/css/font-awesome.min.css', __FILE__)
        );
        wp_enqueue_style('footable',
            plugins_url('../resources/css/footable.standalone.min.css', __FILE__)
        );
         wp_enqueue_style('paydirekt-transactions',
            plugins_url('../resources/css/paydirekt-transactions.css', __FILE__)
        );
        wp_enqueue_script('jquery-ui-core');
        wp_enqueue_script('jquery-ui-datepicker');
        wp_enqueue_script('paydirekt-footable',
            plugins_url('../resources/js/footable.min.js', __FILE__),
            array(PAYDIREKT_JQUERY),
            null,
            true
        );
        wp_enqueue_script('paydirekt-transactions',
            plugins_url('../resources/js/paydirekt-transactions.js', __FILE__),
            array(PAYDIREKT_JQUERY),
            null,
            true
        );

        $this->prepare_items();
        $this->render();
    }

    public function getPaydirektColumns()
    {
        return array(
            PAYDIREKT_TRANSACTION_AMOUNT => __('Betrag', PAYDIREKT_PAYMENT_ID),
            PAYDIREKT_TRANSACTION_DATE => __('Datum', PAYDIREKT_PAYMENT_ID),
            PAYDIREKT_CHECKOUT_ID => __('Transaktions-ID', PAYDIREKT_PAYMENT_ID),
            PAYDIREKT_MERCHANT_REFERENCE => __('Bestellnummer', PAYDIREKT_PAYMENT_ID),
            PAYDIREKT_STATUS => __('Status', PAYDIREKT_PAYMENT_ID),
            PAYDIREKT_ACTION => __('Aktion', PAYDIREKT_PAYMENT_ID),
        );
    }

    private function getPaydirektData()
    {
        $orders = array();
        $params = array(
            'payment_method' => PAYDIREKT_PAYMENT_ID,
            'limit' => -1,
        );
        foreach (\wc_get_orders($params) as $order) {
            if (PAYDIREKT_COMPATIBILITY ? $order->payment_method_title : $order->get_payment_method_title() == PAYDIREKT_PAYMENT_TITLE) {
                $orders[] = $order;
            }
        }
        return $orders;
    }

    public function prepare_items()
    {
        $paydirektData = $this->getPaydirektData();
        $columns = $this->getPaydirektColumns();

        $this->setColumns($columns);
        if (isset($paydirektData)) {
            $this->setData($paydirektData);
        }
    }

    public function renderColumn($column, $data, $rowData=null)
    {
        $columnData = $data;
        switch ($column) {
            case PAYDIREKT_TRANSACTION_AMOUNT:
                $columnData = number_format((float) $columnData, 2, ',', '') . " " . $rowData[PAYDIREKT_TRANSACTION_CURRENCY];
                break;
            case PAYDIREKT_STATUS:
                $columnData = __($columnData, 'fulino-paydirekt');
                break;
            default:
                break;
        }

        return $columnData;
    }

    public function renderRow($rowIndex, $data, $columns)
    {
        $row = "</tr>";
        $order_id = PAYDIREKT_COMPATIBILITY ? $data[$rowIndex]->id :$data[$rowIndex]->get_id();
        $overview_url = wp_nonce_url(admin_url('admin.php?page=paydirekt-orderview&order_id=' . $order_id));
        $orderData[$rowIndex][PAYDIREKT_TRANSACTION_AMOUNT] = $data[$rowIndex]->get_total();
        $orderData[$rowIndex][PAYDIREKT_TRANSACTION_DATE] = PAYDIREKT_COMPATIBILITY ? $data[$rowIndex]->order_date :$data[$rowIndex]->get_date_created();
        $orderData[$rowIndex][PAYDIREKT_CHECKOUT_ID] = $data[$rowIndex]->get_transaction_id();
        $orderData[$rowIndex][PAYDIREKT_MERCHANT_REFERENCE] = $data[$rowIndex]->get_order_number();
        $orderData[$rowIndex][PAYDIREKT_STATUS] = $data[$rowIndex]->get_status();
        $orderData[$rowIndex][PAYDIREKT_ACTION] = "<a href='" . $overview_url . "' class='button button-primary'>" 
        . __('to transaction', PAYDIREKT_PAYMENT_ID) 
        . "</a>";

        foreach ($columns as $columnIndex => $columnName) {
            if (isset($orderData[$rowIndex][$columnIndex]) && !is_array($orderData[$rowIndex][$columnIndex])) {
                $renderData = $this->renderColumn($columnIndex, $orderData[$rowIndex][$columnIndex], $orderData[$rowIndex]);
                $row .= $this->renderCell($columnIndex, $renderData);
            } else {
                $row .= $this->renderCell($columnIndex, "");
            }
        }
        return $row . "</tr>";
    }
}
