<?php
/**
 * @category    Payment Plugin
 * @package     paydirekt
 * @author      Logata Digital Solutions GmbH
 * @copyright   Logata Digital Solutions GmbH
 * @license     https://logata.com/paydirekt-lizenzbedingungen
 * @version     1.0.44
 * @link        https://www.paydirekt.de
 */

namespace Bitergo\PaydirektWooCommerce\classes;

if (!defined('ABSPATH')) {
    exit;
}
class PaydirektUtils
{

    /**
     * splits the complete street and number string to an array("name" => "musterstr", "number" => "123")
     * There are also some tweaks to get the correct street, even if there is a number in the streetname
     *
     * @param string $streetWithNumber
     * @return void
     */
    public static function splitStreetAndNumber($streetWithNumber)
    {
        preg_match("/^(\d*[\wäöüß\d '\-\.]+)[,\s]+(\d+)\s*([\wäöüß\d\-\/]*)$/", $streetWithNumber, $match_output);
        $streetInfo = array(
            'name' => '',
            'number' => '',
        );
        if (empty($match_output)) {
            $streetInfo['name'] = $streetWithNumber;
        } else {
            $streetInfo['name'] = $match_output[1];
            $streetInfo['number'] = implode(array_slice($match_output, 2));
        }
        return $streetInfo;
    }

    public static function getHash()
    {
        return md5(uniqid('', true));
    }

    public static function getConfig($key = null)
    {
        $settings = get_option("woocommerce_fulino-paydirekt_settings");
        if ($settings != false && $key != null && array_key_exists($key, $settings)) {
            return $settings[$key];
        }

        return $settings;
    }

    public static function addCaptureRefundData($checkout, $decoded = false)
    {
        if (!$decoded) {
            $checkout = json_decode($checkout, true);
        }

        $decodedCheckout = $checkout;
        $encodedCheckout = null;
        $embedded = isset($decodedCheckout[PAYDIREKT_EMBEDDED]) ? $decodedCheckout[PAYDIREKT_EMBEDDED] : array();

        $encodedCheckout = array();
        $encodedCheckout[PAYDIREKT_CHECKOUTS] = array();
        $encodedCheckout[PAYDIREKT_CAPTURE_REFUND_DATA] = array();

        $encodedCheckout[PAYDIREKT_CHECKOUTS][] = $decodedCheckout;

        $countCaptures = 0;
        $sumCaptures = 0;
        if (($decodedCheckout[PAYDIREKT_TYPE] == "ORDER" || $decodedCheckout[PAYDIREKT_TYPE] == "ORDER_SECURED") && $decodedCheckout[PAYDIREKT_STATUS] == "APPROVED") {
            $restCapturable = $decodedCheckout[PAYDIREKT_TOTAL_AMOUNT];
            $capturableTill = strtotime("+182 days", strtotime($decodedCheckout['creationTimestamp']));
        }

        $countRefunds = 0;
        $restRefunds = 0;
        $sumRefunds = 0;

        if (!empty($embedded)) {
            if (isset($embedded[PAYDIREKT_CAPTURES])) {
                $captures = $embedded[PAYDIREKT_CAPTURES];
            }
            if (isset($embedded[PAYDIREKT_REFUNDS])) {
                $refunds = $embedded[PAYDIREKT_REFUNDS];
            }
            if (!empty($captures) && $decodedCheckout[PAYDIREKT_TYPE] != "DIRECT_SALE") {
                $countCaptures = count($embedded[PAYDIREKT_CAPTURES]);
                foreach ($captures as $capture) {
                    if ($capture[PAYDIREKT_STATUS] == "SUCCESSFUL") {
                        if (($decodedCheckout[PAYDIREKT_TYPE] == "ORDER" || $decodedCheckout[PAYDIREKT_TYPE] == "ORDER_SECURED")
                            && $decodedCheckout[PAYDIREKT_STATUS] == "APPROVED") {
                            $restCapturable -= $capture[PAYDIREKT_AMOUNT];
                        }
                        $sumCaptures += $capture[PAYDIREKT_AMOUNT];
                    }
                    $capture[PAYDIREKT_CURRENCY] = $decodedCheckout[PAYDIREKT_CURRENCY];
                    $capture[PAYDIREKT_TOTAL_AMOUNT] = $capture[PAYDIREKT_AMOUNT];
                    $capture[PAYDIREKT_CHECKOUTID] = $decodedCheckout[PAYDIREKT_CHECKOUTID];
                    $encodedCheckout[PAYDIREKT_CHECKOUTS][] = $capture;
                }
            }

            if (!empty($refunds)) {
                $countRefunds = count($refunds);

                foreach ($refunds as $refund) {
                    $sumRefunds += $refund[PAYDIREKT_AMOUNT];
                    $refund[PAYDIREKT_CURRENCY] = $decodedCheckout[PAYDIREKT_CURRENCY];
                    $refund[PAYDIREKT_TOTAL_AMOUNT] = $refund[PAYDIREKT_AMOUNT];
                    $refund[PAYDIREKT_CHECKOUTID] = $decodedCheckout[PAYDIREKT_CHECKOUTID];
                    $encodedCheckout[PAYDIREKT_CHECKOUTS][] = $refund;
                }
            }

            $refundLimit = !empty($decodedCheckout['refundLimit']) ? $decodedCheckout['refundLimit'] : 200;
            if ($sumCaptures == 0) {
                $sumCapturesForCalc = $decodedCheckout[PAYDIREKT_TOTAL_AMOUNT];
            } else {
                $sumCapturesForCalc = $sumCaptures;
            }
            $restRefunds = ($sumCapturesForCalc * $refundLimit / 100) - $sumRefunds;
        }

        $testTransaction = true;
        if (strpos($decodedCheckout['_links']['self']['href'], "sandbox") == false) {
            $testTransaction = false;
        }

        for ($i = 0; $i < count($encodedCheckout[PAYDIREKT_CHECKOUTS]); $i++) {
            $encodedCheckout[PAYDIREKT_CHECKOUTS][$i][PAYDIREKT_TEST_TRANSACTION] = $testTransaction;
        }

        $encodedCheckout[PAYDIREKT_CAPTURE_REFUND_DATA][PAYDIREKT_COUNT_CAPTURES] = $countCaptures;
        $encodedCheckout[PAYDIREKT_CAPTURE_REFUND_DATA][PAYDIREKT_SUM_CAPTURES] = $sumCaptures;
        $encodedCheckout[PAYDIREKT_CAPTURE_REFUND_DATA][PAYDIREKT_REST_CAPTURABLE] = isset($restCapturable) ? $restCapturable : 0;
        $encodedCheckout[PAYDIREKT_CAPTURE_REFUND_DATA][PAYDIREKT_CAPTURABLE_TILL] = isset($capturableTill) ? $capturableTill : 0;

        $encodedCheckout[PAYDIREKT_CAPTURE_REFUND_DATA][PAYDIREKT_COUNT_REFUNDS] = $countRefunds;
        $encodedCheckout[PAYDIREKT_CAPTURE_REFUND_DATA][PAYDIREKT_REST_REFUNDS] = $restRefunds;
        $encodedCheckout[PAYDIREKT_CAPTURE_REFUND_DATA][PAYDIREKT_SUM_REFUNDS] = $sumRefunds;

        if (!$decoded) {
            $encodedCheckout = json_encode($encodedCheckout);
        }
        return $encodedCheckout;
    }

    public static function createFormElement($type, $name, $class, $value = false, $onClick = false, $selectedValue = false)
    {
        if ($onClick !== false) {
            $onClickString = " onclick='" . $onClick . "'";
        }
        if ($value !== false) {
            $valueString = " value='" . $value . "'";
        }
        if ($type == "select" && $value !== false) {
            $valueString = "";
            if (is_array($value)) {
                foreach ($value as $optionValue => $optionLabel) {
                    if ($selectedValue !== false && $selectedValue == $optionValue) {
                        $additionals .= " selected='selected' ";
                    }
                    $valueString .= "<option value='" . $optionValue . "' " . $additionals . ">" . $optionLabel . "</option>";
                }
            }
            $field .= "<select name='" . $name . "'>";
            $field .= $valueString;
            $field .= "</select>";
            $field .= $help;
        } else {
            $field = "<input type='" . $type . "'  name='" . $name . "'class='" . $class . "' " . $valueString . " />" . $help;
        }

        // return "<input type='" . $type . "' name='" . $name . "' " . $onClickString . " class='" . $class . "' " . $valueString . " />"
        return $field;
    }

    public static function createFormElementRow($type, $labelText, $name, $helpText = false, $value = false, $selectedValue = false)
    {
        $label = "";
        $field = "";
        $help = "";
        $additionals = "";

        if ($helpText !== false) {
            $help = "<p class='description'>" . $helpText . "</p>";
        }

        $label .= "<th>" . $labelText . "</th>";

        if ($type == "select" && $value !== false) {
            $valueString = "";
            if (is_array($value)) {
                foreach ($value as $optionValue => $optionLabel) {
                    if ($selectedValue !== false && $selectedValue == $optionValue) {
                        $additionals .= " selected='selected' ";
                    }
                    $valueString .= "<option value='" . $optionValue . "' " . $additionals . ">" . $optionLabel . "</option>";
                }
            }
            $field .= "<select name='" . $name . "'>";
            $field .= $valueString;
            $field .= "</select>";
            $field .= $help;
        } else {
            if ($value !== false) {
                $valueParam = " value='" . $value . "'";
            } else {
                $valueParam = "";
            }
            $field = "<input type='" . $type . "' name='" . $name . "' class='paydirekt-" . $name . "' " . $valueParam . " />" . $help;
        }

        return "<tr>" . $label . "<td>" . $field . "</td></tr>";
    }

    public static function createButtonElement($actionUrl, $class, $label, $name)
    {
        return "<a href='" . $actionUrl . "' class='" . $class . "' name='" . $name . "'>" . $label . "</a>";
    }

    public static function alert($type, $message, $return = false)
    {
        $js = "<script type='text/javascript'>";
        $js .= "jQuery(document).ready(function () {";
        switch ($type) {
            case "error":
                $js .= "jQuery.growl.error({ message: '" . $message . "', fixed: true, location: 'tc', size:'large'});";
                break;
            case "warning":
                $js .= "jQuery.growl.warning({ message: '" . $message . "' , fixed: true, location: 'tc', size:'large'});";
                break;
            case "info":
            case "success":
                $js .= "jQuery.growl.notice({ message: '" . $message . "', location: 'tc', size:'large'});";
                break;
            default:
                break;
        }
        $js .= "});";
        $js .= "</script>";
        if ($return) {
            return $js;
        }
        echo ($js);
    }

    public static function redirect($url, $status = 302)
    {
        if (is_array($url)) {
            $url = $url['redirect'];
        }
        header("Location: $url", true, $status);
    }

    public static function getSettings($order = null)
    {
        $settings = get_option(PAYDIREKT_WOOCOMMERCE_PAYDIREKT_SETTINGS);
        if ($order !== null) {
            $settings = static::renderConfigurationVariables($settings, $order);
        }

        return $settings;
    }

    /**
     * traverse over all configParameter and returns the replaced placeholder
     *
     * @param array $configurationArray
     * @param object $order
     * @return array
     */
    public static function renderConfigurationVariables($configurationArray, $order)
    {
        if (!isset($order)) {
            return $configurationArray;
        }

        $first_name = ""; 
        $last_name = ""; 
        $user_id = ""; 

        $user = $order->get_user(); 
        // if user is FALSE, this is a anonymous order 
        if ($user !== false) { 
            $first_name = $user->get('first_name'); 
            $last_name = $user->get('last_name'); 
            $user_id = $user->get('id'); 
        } 
        $order_number = $order->get_order_number();
        $order_date = PAYDIREKT_COMPATIBILITY ? $order->date_created : $order->get_date_created();

        foreach ($configurationArray as $key => $value) {
            $configurationArray[$key] = str_ireplace(
                array(
                    "{{bestellnummer}}",
                    "{{kundennummer}}",
                    "{{vorname}}",
                    "{{name}}",
                    "{{bestelldatum}}",
                ),
                array(
                    $order_number,
                    $user_id,
                    $first_name,
                    $last_name,
                    $order_date,
                ), $value);
        }

        return $configurationArray;
    }
    public static function removeConfigurationVariablesFromString($value)
    {
        return str_ireplace(
            array(
                "{{bestellnummer}}",
                "{{kundennummer}}",
                "{{vorname}}",
                "{{name}}",
                "{{bestelldatum}}",
            ), array("", "", "", "", ""), $value);
    }
}
