<?php
/**
 * @category    Payment Plugin
 * @package     paydirekt
 * @author      Logata Digital Solutions GmbH
 * @copyright   Logata Digital Solutions GmbH
 * @license     https://logata.com/paydirekt-lizenzbedingungen
 * @version     1.0.44
 * @link        https://www.paydirekt.de
 */

namespace Bitergo\PaydirektWooCommerce\classes\components;

if (!defined('ABSPATH')) {
    exit;
}
class PaydirektActionButtons
{

    private $paydirektCheckoutData;
    private $checkoutType;
    private $checkoutId;
    private $orderId;

    public function __construct($paydirektCheckoutData)
    {
        $this->paydirektCheckoutData = $paydirektCheckoutData;
    }

    public function render()
    {
        $closeOrderUrl = wp_nonce_url(
            admin_url('admin.php?page=paydirekt-orderview&order_id=' . $this->orderId . '&action=close-order'), 'paydirekt-close-order'
        );
        $captureUrl = wp_nonce_url(
            admin_url('admin.php?page=paydirekt-capture&checkout_id=' . $this->checkoutId . '&order_id=' . $this->orderId), 'paydirekt-capture'
        );
        $refundUrl = wp_nonce_url(
            admin_url('admin.php?page=paydirekt-refund&checkout_id=' . $this->checkoutId . '&order_id=' . $this->orderId), 'paydirekt-refund'
        );

        ?>
        <a href="<?php echo $refundUrl?>" class="button-primary paydirekt-refund-button"><?php echo __("refund", "fulino-paydirekt")?></a>
        <?php if (($this->checkoutType == "ORDER" || $this->checkoutType == "ORDER_SECURED") && $this->checkoutStatus !== "CLOSED"): ?>
            <a href="<?php echo $captureUrl?>" class="button-primary paydirekt-capture-button">
                <?php echo __("capture", PAYDIREKT_PAYMENT_ID)?>
            </a>
            <a href="<?php echo $closeOrderUrl?>" class="button-secondary delete paydirekt-close-order-button">
                <?php echo __("close_order", PAYDIREKT_PAYMENT_ID)?>
            </a>
        <?php else: ?>
            <a href="#" class="button-primary disabled paydirekt-capture-button">
                <?php echo __("capture", PAYDIREKT_PAYMENT_ID)?>
            </a>
        <?php endif;?>
        <?php
}

    public function prepare_items()
    {
        $this->orderId = wc_sanitize_order_id($_GET['order_id']);
        foreach ($this->paydirektCheckoutData as $checkout) {
            if (isset($checkout['type'])
                && $checkout['type'] == "ORDER"
                || $checkout['type'] == "DIRECT_SALE"
                || $checkout['type'] == "ORDER_SECURED") {
                $this->checkoutType = $checkout['type'];
                $this->checkoutId = $checkout['checkoutId'];
                $this->checkoutStatus = $checkout['status'];
            }
        }
    }
}