<?php
/**
 * @category    Payment Plugin
 * @package     paydirekt
 * @author      Logata Digital Solutions GmbH
 * @copyright   Logata Digital Solutions GmbH
 * @license     https://logata.com/paydirekt-lizenzbedingungen
 * @version     1.0.44
 * @link        https://www.paydirekt.de
 */

namespace Bitergo\PaydirektWooCommerce\classes\components;

if (!defined('ABSPATH')) {
    exit;
}
class PaydirektFormElement
{
    const PAYDIREKT_FORMTYPE_BUTTON = "button";
    const PAYDIREKT_FORMTYPE_SELECT = "select";
    const PAYDIREKT_FORMTYPE_TEXT = "text";
    const PAYDIREKT_FORMTYPE_NUMBER = "number";
    const PAYDIREKT_FORMTYPE_EMAIL = "email";

    private $type;
    private $name;
    private $class;
    private $value;
    private $selectedValue;
    private $onclick;
    private $label;
    private $help;
    private $id;
    private $htmlTable;

    public function __construct($type = false, $name = false, $class = false, $value = false, $selectedValue = false,
        $label = false, $help = false, $id = false, $onclick = false, $htmlTable = false) {

        $this->type = $type;
        $this->name = $name;
        $this->class = $class;
        $this->value = $value;
        $this->selectedValue = $selectedValue;
        $this->onclick = $onclick;
        $this->label = $label;
        $this->help = $help;
        $this->id = $id;
        return $this;
    }

    public function getType()
    {
        return $this->type;
    }

    public function setType($type)
    {
        $this->type = $type;
    }

    public function getName()
    {
        return $this->name;
    }

    public function setName($name)
    {
        $this->name = $name;
    }

    public function getClass()
    {
        return $this->class;
    }

    public function setClass($class)
    {
        $this->class = $class;
    }

    public function getValue()
    {
        return $this->value;
    }

    public function setValue($value)
    {
        $this->value = $value;
    }
    public function addValue($key, $value)
    {
        $this->value[$key] = $value;
    }

    public function getOnclick()
    {
        return $this->onclick;
    }

    public function setOnclick($onclick)
    {
        $this->onclick = $onclick;
    }

    public function getLabel()
    {
        return $this->label;
    }

    public function setLabel($label)
    {
        $this->label = $label;
    }

    public function getHelp()
    {
        return $this->help;
    }

    public function setHelp($help)
    {
        $this->help = $help;
    }

    public function getId()
    {
        return $this->id;
    }

    public function setId($id)
    {
        $this->id = $id;
    }

    public function getHtmlTable()
    {
        return $this->htmlTable;
    }

    public function setHtmlTable($htmlTable)
    {
        $this->htmlTable = $htmlTable;
    }

    public function getSelectedValue()
    {
        return $this->selectedValue;
    }

    public function setSelectedValue($selectedValue)
    {
        $this->selectedValue = $selectedValue;
    }

    private function replaceHtml($label = false, $field = false, $help = false)
    {
        $html = "";
        $labelHtml = "";
        $helpHtml = "";

        if ($label !== false) {
            $labelHtml = "<th>" . $label . "</th>";
        }
        if ($help !== false) {
            $helpHtml = "<p class='description'>" . $help . "</p>";
            $field .= $htlpHtml;
        }
        if ($field !== false) {
            $html = "<tr>" . $labelHtml . "<td>" . $field . "</td></tr>";
        }

        return $html;
    }

    private function renderButton()
    {
        return "<input type='submit' name='$this->name' class='$this->class' onclick='$this->onclick' value='$this->value' id='$this->id' />";
    }

    private function renderSelect()
    {
        $selectHtml = "<select class='$this->class' name='$this->name' onclick='$this->onclick' id='$this->id'>";
        if (is_array($this->value)) {
            foreach ($this->value as $optionValue => $optionLabel) {
                $additionals = "";
                if ($this->selectedValue !== false && $this->selectedValue == $optionValue) {
                    $additionals .= " selected ";
                }

                $selectHtml .= "<option value='" . $optionValue . "' " . $additionals . ">" . $optionLabel . "</option>";
            }
        }
        return $selectHtml .= "</select>";
    }

    private function renderText()
    {
        return "<input type='$this->type' name='$this->name' class='$this->class' onclick='$this->onclick' value='$this->value' id='$this->id' />";
    }

    public function render()
    {
        $field = null;

        switch ($this->type) {
            case static::PAYDIREKT_FORMTYPE_BUTTON:
                $field = $this->renderButton();
                break;
            case static::PAYDIREKT_FORMTYPE_SELECT:
                $field = $this->renderSelect();
                break;
            case static::PAYDIREKT_FORMTYPE_TEXT:
            case static::PAYDIREKT_FORMTYPE_NUMBER:
            case static::PAYDIREKT_FORMTYPE_EMAIL:
                $field = $this->renderText();
                break;
            default:
                break;
        }

        if ($this->htmlTable !== false) {
            $field = $this->replaceHtml($this->label, $field, $this->help);
        }

        return $field;
    }
}
