<?php
/**
 * @category    Payment Plugin
 * @package     paydirekt
 * @author      Logata Digital Solutions GmbH
 * @copyright   Logata Digital Solutions GmbH
 * @license     https://logata.com/paydirekt-lizenzbedingungen
 * @version     1.0.44
 * @link        https://www.paydirekt.de
 */

namespace Bitergo\PaydirektWooCommerce\classes\components;
use Bitergo\PaydirektWooCommerce\classes\components\PaydirektPanel;
use Bitergo\PaydirektWooCommerce\classes\PaydirektUtils;
use Bitergo\PaydirektWooCommerce\classes\models\PaydirektPanelData;

if (!defined('ABSPATH')) {
    exit;
}
class PaydirektOrderDetailPanel extends PaydirektPanel
{
    private $paydirektCheckoutData;
    private $transactionId;
    private $paydirektPanelData = [];

    public function __construct($paydirektCheckoutData, $transactionId = null)
    {
        $this->paydirektCheckoutData = $paydirektCheckoutData;
        $this->transactionId = $transactionId;
    }

    public function prepare_items()
    {
        $selectedItem = null;
        for ($i = 0; $i < count($this->paydirektCheckoutData); $i++) {
            if (isset($this->paydirektCheckoutData[$i][PAYDIREKT_CHECKOUTID])) {
                if ($this->transactionId == null) {
                    $selectedItem = PaydirektUtils::addCaptureRefundData($this->paydirektCheckoutData[$i], true);
                    break;
                } else {
                    if ($this->paydirektCheckoutData[$i][PAYDIREKT_CHECKOUTID] == $this->transactionId) {
                        $selectedItem = PaydirektUtils::addCaptureRefundData($this->paydirektCheckoutData[$i], true);
                    }
                }
            } else if (isset($this->paydirektCheckoutData[$i][PAYDIREKT_TRANSACTIONID])
                && $this->paydirektCheckoutData[$i][PAYDIREKT_TRANSACTIONID] == $this->transactionId) {
                $selectedItem = PaydirektUtils::addCaptureRefundData($this->paydirektCheckoutData[$i], true);
            }
        }

        switch ($selectedItem[PAYDIREKT_CHECKOUTS][0]['type']) {
            case "CAPTURE_DIRECT_SALE":
            case "CAPTURE_ORDER":
                $this->addCaptureData($selectedItem[PAYDIREKT_CHECKOUTS][0]);
                break;
            case "REFUND":
                $this->addRefundData($selectedItem[PAYDIREKT_CHECKOUTS][0]);
                break;
            case "ORDER":
            case "DIRECT_SALE":
            case "ORDER_SECURED":
            default:
                $this->addCheckoutData($selectedItem[PAYDIREKT_CHECKOUTS][0]);
                break;
        }
        $this->setData($this->paydirektPanelData);
    }

    public function addCheckoutData($selectedCheckout)
    {
        $this->addItem(PAYDIREKT_CHECKOUTID,
            $selectedCheckout[PAYDIREKT_CHECKOUTID],
            __(PAYDIREKT_CHECKOUTID, PAYDIREKT_PAYMENT_ID),
            PAYDIREKT_LEFT
        );
        $this->addItem(PAYDIREKT_TYPE,
            __($selectedCheckout[PAYDIREKT_TYPE], PAYDIREKT_PAYMENT_ID),
            __(PAYDIREKT_TYPE, PAYDIREKT_PAYMENT_ID),
            PAYDIREKT_LEFT
        );
        $this->addItem(PAYDIREKT_CREATION_TIMESTAMP,
            $selectedCheckout[PAYDIREKT_CREATION_TIMESTAMP],
            __(PAYDIREKT_CREATION_TIMESTAMP, PAYDIREKT_PAYMENT_ID),
            PAYDIREKT_LEFT
        );
        $this->addItem(PAYDIREKT_TOTAL_AMOUNT,
            $selectedCheckout[PAYDIREKT_TOTAL_AMOUNT] . " " . $selectedCheckout[PAYDIREKT_CURRENCY],
            __(PAYDIREKT_TOTAL_AMOUNT, PAYDIREKT_PAYMENT_ID),
            PAYDIREKT_LEFT,
            PAYDIREKT_CURRENCY
        );
        $this->addItem(PAYDIREKT_SHIPPING_AMOUNT,
            $selectedCheckout[PAYDIREKT_SHIPPING_AMOUNT] . " " . $selectedCheckout[PAYDIREKT_CURRENCY],
            __(PAYDIREKT_SHIPPING_AMOUNT, PAYDIREKT_PAYMENT_ID),
            PAYDIREKT_LEFT,
            PAYDIREKT_CURRENCY
        );
        $this->addItem(PAYDIREKT_ORDER_AMOUNT,
            $selectedCheckout[PAYDIREKT_ORDER_AMOUNT] . " " . $selectedCheckout[PAYDIREKT_CURRENCY],
            __(PAYDIREKT_ORDER_AMOUNT, PAYDIREKT_PAYMENT_ID),
            PAYDIREKT_LEFT,
            PAYDIREKT_CURRENCY
        );
        $this->addItem(PAYDIREKT_STATUS,
            __($selectedCheckout[PAYDIREKT_STATUS], PAYDIREKT_PAYMENT_ID),
            __(PAYDIREKT_STATUS, PAYDIREKT_PAYMENT_ID),
            PAYDIREKT_LEFT
        );
        $this->addItem(PAYDIREKT_SHOPPING_CART_TYPE,
            __($selectedCheckout[PAYDIREKT_SHOPPING_CART_TYPE], PAYDIREKT_PAYMENT_ID),
            __(PAYDIREKT_SHOPPING_CART_TYPE, PAYDIREKT_PAYMENT_ID),
            PAYDIREKT_LEFT
        );
        $this->addItem(PAYDIREKT_DELIVERY_TYPE,
            $selectedCheckout[PAYDIREKT_DELIVERY_TYPE],
            __(PAYDIREKT_DELIVERY_TYPE, PAYDIREKT_PAYMENT_ID),
            PAYDIREKT_LEFT
        );
        $this->addItem(PAYDIREKT_REFUND_LIMIT,
            isset($selectedCheckout[PAYDIREKT_REFUND_LIMIT]) ? $selectedCheckout[PAYDIREKT_REFUND_LIMIT] : "",
            __(PAYDIREKT_REFUND_LIMIT, PAYDIREKT_PAYMENT_ID),
            PAYDIREKT_LEFT
        );
        $this->addItem(PAYDIREKT_PARAMETER_MINIMUMAGE,
            isset($selectedCheckout[PAYDIREKT_PARAMETER_MINIMUMAGE]) ? $selectedCheckout[PAYDIREKT_PARAMETER_MINIMUMAGE] : "",
            __(PAYDIREKT_PARAMETER_MINIMUMAGE, PAYDIREKT_PAYMENT_ID),
            PAYDIREKT_LEFT
        );
        $this->addItem(PAYDIREKT_TEST_TRANSACTION,
            $selectedCheckout[PAYDIREKT_TEST_TRANSACTION],
            __(PAYDIREKT_TEST_TRANSACTION, PAYDIREKT_PAYMENT_ID),
            PAYDIREKT_LEFT,
            PAYDIREKT_BOOLEAN
        );

        $this->addItem(PAYDIREKT_MERCHANT_CUSTOMER_NUMBER,
            $selectedCheckout[PAYDIREKT_MERCHANT_CUSTOMER_NUMBER],
            __(PAYDIREKT_MERCHANT_CUSTOMER_NUMBER, PAYDIREKT_PAYMENT_ID),
            PAYDIREKT_RIGHT
        );
        $this->addItem(PAYDIREKT_MERCHANT_ORDER_REFERENCE_NUMBER,
            $selectedCheckout[PAYDIREKT_MERCHANT_ORDER_REFERENCE_NUMBER],
            __(PAYDIREKT_MERCHANT_ORDER_REFERENCE_NUMBER, PAYDIREKT_PAYMENT_ID),
            PAYDIREKT_RIGHT
        );
        $this->addItem(PAYDIREKT_MERCHANT_INVOICE_REFERENCE_NUMBER,
            isset($selectedCheckout[PAYDIREKT_MERCHANT_INVOICE_REFERENCE_NUMBER]) ?
            $selectedCheckout[PAYDIREKT_MERCHANT_INVOICE_REFERENCE_NUMBER] :
            "",
            __(PAYDIREKT_MERCHANT_INVOICE_REFERENCE_NUMBER, PAYDIREKT_PAYMENT_ID),
            PAYDIREKT_RIGHT
        );
        $this->addItem(PAYDIREKT_PARAMETER_MERCHANT_RECONCILATION_REFERENCE_NUMBER,
            $selectedCheckout[PAYDIREKT_PARAMETER_MERCHANT_RECONCILATION_REFERENCE_NUMBER],
            __(PAYDIREKT_PARAMETER_MERCHANT_RECONCILATION_REFERENCE_NUMBER, PAYDIREKT_PAYMENT_ID),
            PAYDIREKT_RIGHT
        );
        $this->addItem(PAYDIREKT_CORRELATION_ID,
            $selectedCheckout[PAYDIREKT_CORRELATION_ID],
            __(PAYDIREKT_CORRELATION_ID, PAYDIREKT_PAYMENT_ID),
            PAYDIREKT_RIGHT
        );
        $this->addItem(PAYDIREKT_PARAMETER_ORDERNOTE,
            $selectedCheckout[PAYDIREKT_PARAMETER_ORDERNOTE],
            __(PAYDIREKT_PARAMETER_ORDERNOTE, PAYDIREKT_PAYMENT_ID),
            PAYDIREKT_RIGHT
        );
        $this->addItem(PAYDIREKT_EXPECTED_SHIPPING_DATE,
            isset($selectedCheckout[PAYDIREKT_EXPECTED_SHIPPING_DATE]) ? $selectedCheckout[PAYDIREKT_EXPECTED_SHIPPING_DATE] : "",
            __(PAYDIREKT_EXPECTED_SHIPPING_DATE, PAYDIREKT_PAYMENT_ID),
            PAYDIREKT_RIGHT
        );
        $this->addItem(PAYDIREKT_LOGISTICS_PROVIDER,
            isset($selectedCheckout[PAYDIREKT_LOGISTICS_PROVIDER]) ? $selectedCheckout[PAYDIREKT_LOGISTICS_PROVIDER] : "",
            __(PAYDIREKT_LOGISTICS_PROVIDER, PAYDIREKT_PAYMENT_ID),
            PAYDIREKT_RIGHT
        );
        $this->addItem(PAYDIREKT_TRACKNG_NUMBER,
            isset($selectedCheckout[PAYDIREKT_TRACKNG_NUMBER]) ? $selectedCheckout[PAYDIREKT_TRACKNG_NUMBER] : "",
            __(PAYDIREKT_TRACKNG_NUMBER, PAYDIREKT_PAYMENT_ID),
            PAYDIREKT_RIGHT
        );
        $shippingAddress = $selectedCheckout[PAYDIREKT_SHIPPING_ADDRESS];
        $shippingAddressField = "";
        $shippingAddressField .= $shippingAddress['addresseeGivenName'] . " " . $shippingAddress['addresseeLastName'];
        $shippingAddressField .= PAYDIREKT_BR_TAG;
        $shippingAddressField .= $shippingAddress['company'];
        $shippingAddressField .= PAYDIREKT_BR_TAG;
        $shippingAddressField .= $shippingAddress['street'] . " " . $shippingAddress['streetNr'];
        $shippingAddressField .= PAYDIREKT_BR_TAG;
        $shippingAddressField .= isset($shippingAddress['additionalAddressInformation']) ? $shippingAddress['additionalAddressInformation'] : "";
        $shippingAddressField .= PAYDIREKT_BR_TAG;
        $shippingAddressField .= $shippingAddress['zip'] . " " . $shippingAddress['city'];
        $shippingAddressField .= PAYDIREKT_BR_TAG;
        $shippingAddressField .= $shippingAddress['countryCode'] . " ";
        if (isset($shippingAddress['state'])) {
            $shippingAddressField .= $shippingAddress['state'];
        }
        $this->addItem(PAYDIREKT_SHIPPING_ADDRESS, $shippingAddressField, __(PAYDIREKT_SHIPPING_ADDRESS, PAYDIREKT_PAYMENT_ID), PAYDIREKT_RIGHT);
    }

    public function addRefundData($selectedRefund)
    {
        $this->addItem(PAYDIREKT_TRANSACTIONID,
            $selectedRefund[PAYDIREKT_TRANSACTIONID],
            __(PAYDIREKT_TRANSACTIONID, PAYDIREKT_PAYMENT_ID),
            PAYDIREKT_LEFT
        );
        $this->addItem(PAYDIREKT_AMOUNT,
            $selectedRefund[PAYDIREKT_AMOUNT],
            __(PAYDIREKT_AMOUNT, PAYDIREKT_PAYMENT_ID),
            PAYDIREKT_LEFT
        );
        $this->addItem(PAYDIREKT_STATUS,
            __($selectedRefund[PAYDIREKT_STATUS], PAYDIREKT_PAYMENT_ID),
            __(PAYDIREKT_STATUS, PAYDIREKT_PAYMENT_ID),
            PAYDIREKT_LEFT
        );
        $this->addItem(PAYDIREKT_REASON,
            __($selectedRefund[PAYDIREKT_REASON], PAYDIREKT_PAYMENT_ID),
            __(PAYDIREKT_REASON, PAYDIREKT_PAYMENT_ID),
            PAYDIREKT_LEFT
        );
        $this->addItem(PAYDIREKT_TEST_TRANSACTION,
            $selectedRefund[PAYDIREKT_TEST_TRANSACTION],
            __(PAYDIREKT_TEST_TRANSACTION, PAYDIREKT_PAYMENT_ID),
            PAYDIREKT_LEFT,
            PAYDIREKT_BOOLEAN
        );

        $this->addItem(PAYDIREKT_MERCHANT_REFUND_REFERENCE_NUMBER,
            $selectedRefund[PAYDIREKT_MERCHANT_REFUND_REFERENCE_NUMBER],
            __(PAYDIREKT_MERCHANT_REFUND_REFERENCE_NUMBER, PAYDIREKT_PAYMENT_ID),
            PAYDIREKT_RIGHT
        );
        $this->addItem(PAYDIREKT_PARAMETER_MERCHANT_RECONCILATION_REFERENCE_NUMBER,
            $selectedRefund[PAYDIREKT_PARAMETER_MERCHANT_RECONCILATION_REFERENCE_NUMBER],
            __(PAYDIREKT_PARAMETER_MERCHANT_RECONCILATION_REFERENCE_NUMBER, PAYDIREKT_PAYMENT_ID),
            PAYDIREKT_RIGHT
        );
        $this->addItem(PAYDIREKT_PAYMENT_INFORMATION_ID,
            $selectedRefund[PAYDIREKT_PAYMENT_INFORMATION_ID],
            __(PAYDIREKT_PAYMENT_INFORMATION_ID, PAYDIREKT_PAYMENT_ID),
            PAYDIREKT_RIGHT
        );
        $this->addItem(PAYDIREKT_PARAMETER_ORDERNOTE,
            $selectedRefund[PAYDIREKT_NOTE],
            __(PAYDIREKT_PARAMETER_ORDERNOTE, PAYDIREKT_PAYMENT_ID),
            PAYDIREKT_RIGHT
        );
    }

    public function addCaptureData($selectedCapture)
    {
        $this->addItem(PAYDIREKT_TRANSACTIONID,
            $selectedCapture[PAYDIREKT_TRANSACTIONID],
            __(PAYDIREKT_TRANSACTIONID, PAYDIREKT_PAYMENT_ID),
            PAYDIREKT_LEFT
        );
        $this->addItem(PAYDIREKT_AMOUNT,
            $selectedCapture[PAYDIREKT_AMOUNT],
            __(PAYDIREKT_AMOUNT, PAYDIREKT_PAYMENT_ID),
            PAYDIREKT_LEFT
        );
        $this->addItem(PAYDIREKT_STATUS,
            __($selectedCapture[PAYDIREKT_STATUS], PAYDIREKT_PAYMENT_ID),
            __(PAYDIREKT_STATUS, PAYDIREKT_PAYMENT_ID),
            PAYDIREKT_LEFT
        );
        $this->addItem(PAYDIREKT_FINAL_CAPTURE,
            $selectedCapture[PAYDIREKT_FINAL_CAPTURE],
            __(PAYDIREKT_FINAL_CAPTURE, PAYDIREKT_PAYMENT_ID),
            PAYDIREKT_LEFT,
            PAYDIREKT_BOOLEAN
        );
        $this->addItem(PAYDIREKT_TEST_TRANSACTION,
            $selectedCapture[PAYDIREKT_TEST_TRANSACTION],
            __(PAYDIREKT_TEST_TRANSACTION, PAYDIREKT_PAYMENT_ID),
            PAYDIREKT_LEFT,
            PAYDIREKT_BOOLEAN
        );
        $this->addItem(PAYDIREKT_MERCHANT_CAPTURE_REFERENCE_NUMBER,
            $selectedCapture[PAYDIREKT_MERCHANT_CAPTURE_REFERENCE_NUMBER],
            __(PAYDIREKT_MERCHANT_CAPTURE_REFERENCE_NUMBER, PAYDIREKT_PAYMENT_ID),
            PAYDIREKT_RIGHT
        );
        $this->addItem(PAYDIREKT_PARAMETER_MERCHANT_RECONCILATION_REFERENCE_NUMBER,
            $selectedCapture[PAYDIREKT_PARAMETER_MERCHANT_RECONCILATION_REFERENCE_NUMBER],
            __(PAYDIREKT_PARAMETER_MERCHANT_RECONCILATION_REFERENCE_NUMBER, PAYDIREKT_PAYMENT_ID),
            PAYDIREKT_RIGHT
        );
        $this->addItem(PAYDIREKT_CAPTURE_INVOICE_REFERENCE_NUMBER,
            $selectedCapture[PAYDIREKT_CAPTURE_INVOICE_REFERENCE_NUMBER],
            __(PAYDIREKT_CAPTURE_INVOICE_REFERENCE_NUMBER, PAYDIREKT_PAYMENT_ID),
            PAYDIREKT_RIGHT
        );
        $this->addItem(PAYDIREKT_PAYMENT_INFORMATION_ID,
            $selectedCapture[PAYDIREKT_PAYMENT_INFORMATION_ID],
            __(PAYDIREKT_PAYMENT_INFORMATION_ID, PAYDIREKT_PAYMENT_ID),
            PAYDIREKT_RIGHT
        );
        $this->addItem(PAYDIREKT_EXPECTED_SHIPPING_DATE,
            $selectedCapture[PAYDIREKT_DELIVERY_INFORMATION][PAYDIREKT_EXPECTED_SHIPPING_DATE],
            __(PAYDIREKT_EXPECTED_SHIPPING_DATE, PAYDIREKT_PAYMENT_ID),
            PAYDIREKT_RIGHT
        );
        $this->addItem(PAYDIREKT_LOGISTICS_PROVIDER,
            $selectedCapture[PAYDIREKT_DELIVERY_INFORMATION][PAYDIREKT_LOGISTICS_PROVIDER],
            __(PAYDIREKT_LOGISTICS_PROVIDER, PAYDIREKT_PAYMENT_ID),
            PAYDIREKT_RIGHT
        );
        $this->addItem(PAYDIREKT_TRACKNG_NUMBER,
            $selectedCapture[PAYDIREKT_DELIVERY_INFORMATION][PAYDIREKT_TRACKNG_NUMBER],
            __(PAYDIREKT_TRACKNG_NUMBER, PAYDIREKT_PAYMENT_ID),
            PAYDIREKT_RIGHT
        );
        $this->addItem(PAYDIREKT_PARAMETER_ORDERNOTE,
            $selectedCapture[PAYDIREKT_PARAMETER_ORDERNOTE],
            __(PAYDIREKT_PARAMETER_ORDERNOTE, PAYDIREKT_PAYMENT_ID),
            PAYDIREKT_RIGHT
        );
    }

    public function addItem($key, $value, $label, $orientation, $type = null)
    {
        if (empty($value)) {
            $value = "&nbsp;";
        }
        switch ($type) {
            case PAYDIREKT_CURRENCY:
                $value = str_replace(".", ",", $value);
                break;
            case PAYDIREKT_BOOLEAN:
                if ($value === true || $value == "true") {
                    $value = __("yes", 'fulino-paydirekt');
                } else {
                    $value = __("no", 'fulino-paydirekt');
                }
                break;
            default:
                break;
        }
        $panelData = new PaydirektPanelData();
        $panelData->setKey($key);
        $panelData->setValue($value);
        $panelData->setLabel($label);
        $panelData->setOrientation($orientation);
        $this->paydirektPanelData[] = $panelData;
    }

}
