<?php
/**
 * @category    Payment Plugin
 * @package     paydirekt
 * @author      Logata Digital Solutions GmbH
 * @copyright   Logata Digital Solutions GmbH
 * @license     https://logata.com/paydirekt-lizenzbedingungen
 * @version     1.0.44
 * @link        https://www.paydirekt.de
 */


namespace Bitergo\PaydirektWooCommerce\classes\components;

if (!defined('ABSPATH')) {
    exit;
}

use Bitergo\PaydirektWooCommerce\classes\components\PaydirektTable;
use Bitergo\PaydirektWooCommerce\classes\PaydirektUtils;
use Bitergo\PaydirektWooCommerce\Lib\PaydirektLogger;
use Bitergo\PaydirektWoocommerce\Lib\Utils;
use Bitergo\PaydirektWooCommerce\Lib\Token;
use Bitergo\PaydirektWooCommerce\Lib\Checkout;

class PaydirektOrderdetailTable extends PaydirektTable
{

    private $logger;
    private $order;
    private $tableData;

    public function __construct()
    {
        $logLevel = PaydirektUtils::getConfig(PAYDIREKT_PARAMETER_LOGLEVEL);
        $this->order = new \WC_Order(wc_sanitize_order_id($_GET['order_id']));
        $this->logger = PaydirektLogger::getInstance(get_class($this), $logLevel);
    }

    public function getPaydirektData()
    {
        $settings = get_option(PAYDIREKT_WOOCOMMERCE_PAYDIREKT_SETTINGS);
        $apiKey = $settings[PAYDIREKT_PARAMETER_APIKEY];
        $apiSecret = $settings[PAYDIREKT_PARAMETER_APISECRET];
        $liveSystem = Utils::isLiveSystem($apiKey);
        $checkoutId = $this->order->get_transaction_id();
        $checkout = null;

        try {
            $token = Token::getToken($apiSecret, $apiKey, $liveSystem);
            $checkout = Checkout::retrieveCheckout($token, $checkoutId, $liveSystem);
            $checkoutMixed = PaydirektUtils::addCaptureRefundData($checkout[PAYDIREKT_RESPONSE]);
            $this->tableData = json_decode($checkoutMixed, true);
        } catch (\Exception $ex) {
            $this->logger->error("Token error: ", $ex->getMessage());
        }

        return $this->tableData;
    }

    public function getPaydirektColumns()
    {
        return array(
            PAYDIREKT_TYPE => __('Buchungstyp'),
            PAYDIREKT_TOTAL_AMOUNT => __('Betrag'),
            PAYDIREKT_STATUS => __('Status'),
            PAYDIREKT_CREATION_TIMESTAMP => __('Datum'),
            PAYDIREKT_MERCHANT_ORDER_REFERENCE_NUMBER => __('Bestellnummer'),
            PAYDIREKT_CHECKOUTID => __('ID'),
            PAYDIREKT_PARAMETER_MERCHANT_RECONCILATION_REFERENCE_NUMBER => __('Referenznummer'),
            PAYDIREKT_PAYMENT_INFORMATION_ID => __('PaymentInformation-ID'),
        );
    }

    // override function
    public function renderColumn($column, $data, $rowData = NULL)
    {
        $columnData = $data;
        switch ($column) {
            case PAYDIREKT_CREATION_TIMESTAMP:
                $columnData = date("d.m.Y H:i:s", strtotime($data));
                break;
            case PAYDIREKT_TOTAL_AMOUNT:
                $columnData = number_format((float) $columnData, 2, ',', '') . " "
                . $this->tableData[PAYDIREKT_CHECKOUTS][0][PAYDIREKT_CURRENCY];
                break;
            case PAYDIREKT_STATUS:
            case PAYDIREKT_TYPE:
                $columnData = __($columnData, 'fulino-paydirekt');
                break;
            default:
                break;
        }
        return $columnData;
    }

    public function renderRow($rowIndex, $data, $columns)
    {
        if ($data[$rowIndex][PAYDIREKT_TYPE] == PAYDIREKT_CHECKOUT_TYPE_ORDER
            || $data[$rowIndex][PAYDIREKT_TYPE] == PAYDIREKT_CHECKOUT_TYPE_DIRECT_SALE
            || $data[$rowIndex][PAYDIREKT_TYPE] == PAYDIREKT_CHECKOUT_TYPE_ORDER_SECURED) {
            $transactionId = $data[$rowIndex][PAYDIREKT_CHECKOUTID];
        } else {
            $transactionId = $data[$rowIndex][PAYDIREKT_TRANSACTIONID];
        }

        $row = "<tr class='paydirekt-detailView' data-paydirekt-id='"
            . $transactionId . "' data-paydirekt-type='"
            . $data[$rowIndex][PAYDIREKT_TYPE] . "' data-paydirekt-checkoutid='"
            . $data[$rowIndex][PAYDIREKT_CHECKOUTID] . "'>";

        foreach ($columns as $columnIndex => $columnName) {
            if (isset($data[$rowIndex][$columnIndex]) && !is_array($data[$rowIndex][$columnIndex])) {
                $renderData = $this->renderColumn($columnIndex, $data[$rowIndex][$columnIndex]);
                $row .= $this->renderCell($columnIndex, $renderData);
            } else {
                $row .= $this->renderCell($columnIndex, "");
            }
        }
        return $row . "</tr>";
    }

    public function renderCell($column, $data)
    {
        return "<td class='data-$column paydirekt-overview-column'>$data</td>";
    }

    public function prepare_items()
    {
        $paydirektData = $this->getPaydirektData();
        $columns = $this->getPaydirektColumns();
        $captureRefundData = $paydirektData[PAYDIREKT_CAPTURE_REFUND_DATA];

        $this->setToolbarData($captureRefundData);
        $this->setColumns($columns);
        $this->setData($paydirektData[PAYDIREKT_CHECKOUTS]);
    }
}
