<?php
/**
 * @category    Payment Plugin
 * @package     paydirekt
 * @author      Logata Digital Solutions GmbH
 * @copyright   Logata Digital Solutions GmbH
 * @license     https://logata.com/paydirekt-lizenzbedingungen
 * @version     1.0.44
 * @link        https://www.paydirekt.de
 */

namespace Bitergo\PaydirektWooCommerce\classes\components;
use Bitergo\PaydirektWooCommerce\Lib\PaydirektLogger;
use Bitergo\PaydirektWooCommerce\classes\components\PaydirektPanel;
use Bitergo\PaydirektWooCommerce\classes\models\PaydirektPanelData;

if (!defined('ABSPATH')) {
    exit;
}
class PaydirektReportDetailPanel extends PaydirektPanel
{
    private $paydirektCheckoutData;
    private $action;
    private $paydirektPanelData = [];
    private $logger;

    public function __construct($paydirektCheckoutData, $action = null)
    {
        $this->logger = PaydirektLogger::getInstance(get_class($this), PaydirektLogger::PAYDIREKT_STATUS_DEBUG);
        $this->paydirektCheckoutData = $paydirektCheckoutData;
        $this->action = $action;
    }

    public function prepare_items()
    {
        $this->addData();
        $this->setData($this->paydirektPanelData);
    }

    public function addData()
    {
        //left
        $this->addItem(PAYDIREKT_VORGANGSNUMMER, "", __(PAYDIREKT_VORGANGSNUMMER, PAYDIREKT_PAYMENT_ID), PAYDIREKT_LEFT);
        $this->addItem(PAYDIREKT_ENDE_ZU_ENDE_REFERENZNUMMER, "", __(PAYDIREKT_ENDE_ZU_ENDE_REFERENZNUMMER, PAYDIREKT_PAYMENT_ID), PAYDIREKT_LEFT);
        $this->addItem(PAYDIREKT_TRANSAKTIONS_TYP, "", __(PAYDIREKT_TRANSAKTIONS_TYP, PAYDIREKT_PAYMENT_ID), PAYDIREKT_LEFT);
        $this->addItem(PAYDIREKT_TRANSAKTIONS_DATUM, "", __(PAYDIREKT_TRANSAKTIONS_DATUM, PAYDIREKT_PAYMENT_ID), PAYDIREKT_LEFT);
        $this->addItem(PAYDIREKT_VALUTA_DATUM, "", __(PAYDIREKT_VALUTA_DATUM, PAYDIREKT_PAYMENT_ID), PAYDIREKT_LEFT);
        $this->addItem(PAYDIREKT_HAENDLER_VERTRAGS_ID, "", __(PAYDIREKT_HAENDLER_VERTRAGS_ID, PAYDIREKT_PAYMENT_ID), PAYDIREKT_LEFT);
        $this->addItem(PAYDIREKT_HAENDLER_ID, "", __(PAYDIREKT_HAENDLER_ID, PAYDIREKT_PAYMENT_ID), PAYDIREKT_LEFT);
        $this->addItem(PAYDIREKT_HAENDLER, "", __(PAYDIREKT_HAENDLER, PAYDIREKT_PAYMENT_ID), PAYDIREKT_LEFT);
        $this->addItem(PAYDIREKT_HAENDLER_KONTO_IBAN, "", __(PAYDIREKT_HAENDLER_KONTO_IBAN, PAYDIREKT_PAYMENT_ID), PAYDIREKT_LEFT);
        $this->addItem(PAYDIREKT_REFERENZNUMMER, "", __(PAYDIREKT_REFERENZNUMMER, PAYDIREKT_PAYMENT_ID), PAYDIREKT_LEFT);
        $this->addItem(PAYDIREKT_TRANSAKTIONS_REFERENZNUMMER, "", __(PAYDIREKT_TRANSAKTIONS_REFERENZNUMMER, PAYDIREKT_PAYMENT_ID), PAYDIREKT_LEFT);
        $this->addItem(PAYDIREKT_HAENDLER_BANK_ID, "", __(PAYDIREKT_HAENDLER_BANK_ID, PAYDIREKT_PAYMENT_ID), PAYDIREKT_LEFT);
        $this->addItem(PAYDIREKT_KAEUFER_BANK_ID, "", __(PAYDIREKT_KAEUFER_BANK_ID, PAYDIREKT_PAYMENT_ID), PAYDIREKT_LEFT);
        $this->addItem(PAYDIREKT_KAEUFER_BANK_NAME, "", __(PAYDIREKT_KAEUFER_BANK_NAME, PAYDIREKT_PAYMENT_ID), PAYDIREKT_LEFT);
        $this->addItem(PAYDIREKT_TRANSAKTIONSBETRAG, "", __(PAYDIREKT_TRANSAKTIONSBETRAG, PAYDIREKT_PAYMENT_ID), PAYDIREKT_LEFT);
        $this->addItem(PAYDIREKT_TRANSAKTIONS_WAEHRUNG, "", __(PAYDIREKT_TRANSAKTIONS_WAEHRUNG, PAYDIREKT_PAYMENT_ID), PAYDIREKT_LEFT);

        //right
        $this->addItem(PAYDIREKT_KAEUFER_BANK_KONZENTRATOR_ID, "", __(PAYDIREKT_KAEUFER_BANK_KONZENTRATOR_ID, PAYDIREKT_PAYMENT_ID), PAYDIREKT_RIGHT);
        $this->addItem(PAYDIREKT_KAEUFER_BANK_KONZENTRATOR_NAME, "", __(PAYDIREKT_KAEUFER_BANK_KONZENTRATOR_NAME, PAYDIREKT_PAYMENT_ID), PAYDIREKT_RIGHT);
        $this->addItem(PAYDIREKT_SHOP_ID, "", __(PAYDIREKT_SHOP_ID, PAYDIREKT_PAYMENT_ID), PAYDIREKT_RIGHT);
        $this->addItem(PAYDIREKT_SHOP_NAME, "", __(PAYDIREKT_SHOP_NAME, PAYDIREKT_PAYMENT_ID), PAYDIREKT_RIGHT);
        $this->addItem(PAYDIREKT_ALTERSPRUEFUNG, "", __(PAYDIREKT_ALTERSPRUEFUNG, PAYDIREKT_PAYMENT_ID), PAYDIREKT_RIGHT);
        $this->addItem(PAYDIREKT_HAENDLER_MCC, "", __(PAYDIREKT_HAENDLER_MCC, PAYDIREKT_PAYMENT_ID), PAYDIREKT_RIGHT);
        $this->addItem(PAYDIREKT_HAENDLER_DBI, "", __(PAYDIREKT_HAENDLER_DBI, PAYDIREKT_PAYMENT_ID), PAYDIREKT_RIGHT);
        $this->addItem(PAYDIREKT_EXPRESS_BESTELLUNG, "", __(PAYDIREKT_EXPRESS_BESTELLUNG, PAYDIREKT_PAYMENT_ID), PAYDIREKT_RIGHT);
        $this->addItem(PAYDIREKT_CHECKOUT_ID, "", __(PAYDIREKT_CHECKOUT_ID, PAYDIREKT_PAYMENT_ID), PAYDIREKT_RIGHT);
        $this->addItem(PAYDIREKT_RECHNUNGSNUMMER, "", __(PAYDIREKT_RECHNUNGSNUMMER, PAYDIREKT_PAYMENT_ID), PAYDIREKT_RIGHT);
        $this->addItem(PAYDIREKT_TEIL_ZAHLUNGS_RECHNUNGSNUMMER, "", __(PAYDIREKT_TEIL_ZAHLUNGS_RECHNUNGSNUMMER, PAYDIREKT_PAYMENT_ID), PAYDIREKT_RIGHT);
        $this->addItem(PAYDIREKT_RECONCILIATIONSNUMMER, "", __(PAYDIREKT_RECONCILIATIONSNUMMER, PAYDIREKT_PAYMENT_ID), PAYDIREKT_RIGHT);
        $this->addItem(PAYDIREKT_PAYMENT_INFORMATION_ID, "", __(PAYDIREKT_PAYMENT_INFORMATION_ID, PAYDIREKT_PAYMENT_ID), PAYDIREKT_RIGHT);
        $this->addItem(PAYDIREKT_RUECKZAHLUNGSGRUND, "", __(PAYDIREKT_RUECKZAHLUNGSGRUND, PAYDIREKT_PAYMENT_ID), PAYDIREKT_RIGHT);
    }

    public function addItem($key, $value, $label, $orientation, $type = null)
    {
        if (empty($value)) {
            $value = "&nbsp;";
        }
        switch ($type) {
            case PAYDIREKT_CURRENCY:
                $value = str_replace(".", ",", $value);
                break;
            case PAYDIREKT_BOOLEAN:
                if ($value === true || $value == "true") {
                    $value = __("yes", 'fulino-paydirekt');
                } else {
                    $value = __("no", 'fulino-paydirekt');
                }
                break;
            default:
                break;
        }
        $panelData = new PaydirektPanelData();
        $panelData->setKey($key);
        $panelData->setValue($value);
        $panelData->setLabel($label);
        $panelData->setOrientation($orientation);
        $this->paydirektPanelData[] = $panelData;
    }
}
