<?php
/**
 * @category    Payment Plugin
 * @package     paydirekt
 * @author      Logata Digital Solutions GmbH
 * @copyright   Logata Digital Solutions GmbH
 * @license     https://logata.com/paydirekt-lizenzbedingungen
 * @version     1.0.44
 * @link        https://www.paydirekt.de
 */

namespace Bitergo\PaydirektWooCommerce\classes\components;

if (!defined('ABSPATH')) {
    exit;
}

use Bitergo\PaydirektWooCommerce\classes\components\PaydirektTable;
use Bitergo\PaydirektWooCommerce\classes\PaydirektUtils;
use Bitergo\PaydirektWooCommerce\Lib\PaydirektLogger;
use Bitergo\PaydirektWooCommerce\Lib\models\ReportRequestModel;
use Bitergo\PaydirektWooCommerce\Lib\Utils;
use Bitergo\PaydirektWooCommerce\Lib\Token;
use Bitergo\PaydirektWooCommerce\Lib\Report;

class PaydirektReportTable extends PaydirektTable
{
    private $logger;
    private $tableData;

    public function __construct()
    {
        $logLevel = PaydirektUtils::getConfig(PAYDIREKT_PARAMETER_LOGLEVEL);
        $this->logger = PaydirektLogger::getInstance(get_class($this), $logLevel);
    }

    public function download()
    {
        $data = $this->getPaydirektReport("csv");

    }

    public function getPaydirektData()
    {
        $data = $this->getPaydirektReport();
        $this->tableData = $data;
        return $this->tableData;
    }

    public function getPaydirektReport($type = null)
    {
        $this->logger->debug("getPaydirektReport: START");
        $reportWithShopData = array();
        $reportRequestModel = new ReportRequestModel();

        $settings = PaydirektUtils::getSettings();
        $apiKey = $settings[PAYDIREKT_PARAMETER_APIKEY];
        $apiSecret = $settings[PAYDIREKT_PARAMETER_APISECRET];
        $liveSystem = Utils::isLiveSystem($apiKey);
        $token = Token::getToken($apiSecret, $apiKey, $liveSystem);

        if (Token::getError()) {
            $this->logger->error("token error", Token::getError());
            return;
        }
        $shopId = "";
        $from = "";
        $to = "";
        $field = "";
        $fieldValue = "";

        if (isset($_GET["from"]) && !empty($_GET['from'])) {
            $from = date(PAYDIREKT_ISO_DATE_FORMAT_MIN, strtotime(sanitize_text_field($_GET["from"])));
            $reportRequestModel->setFrom($from);
        }
        if (isset($_GET["to"]) && !empty($_GET['to'])) {
            $to = date(PAYDIREKT_ISO_DATE_FORMAT_MAX, strtotime(sanitize_text_field($_GET["to"])));
            $reportRequestModel->setTo($to);
        }
        if (isset($_GET[PAYDIREKT_FIELD]) && isset($_GET[PAYDIREKT_FIELDVALUE]) && !empty($_GET[PAYDIREKT_FIELDVALUE])) {
            $field = sanitize_text_field($_GET[PAYDIREKT_FIELD]);
            $fieldValue = sanitize_text_field($_GET[PAYDIREKT_FIELDVALUE]);
            switch ($field) {
                case "reconciliationReferences":
                    $reportRequestModel->setReconciliationReferences(explode(",", $fieldValue));
                    break;
                case "paymentInformationIds":
                    $reportRequestModel->setPaymentInformationIds(explode(",", $fieldValue));
                    break;
                case "merchantReferenceNumbers":
                    $reportRequestModel->setMerchantReferenceNumbers(explode(",", $fieldValue));
                    break;
                case "checkoutInvoiceNumbers":
                    $reportRequestModel->setCheckoutInvoiceNumbers(explode(",", $fieldValue));
                    break;
                case "captureInvoiceNumbers":
                    $reportRequestModel->setCaptureInvoiceNumbers(explode(",", $fieldValue));
                    break;
                default:
                    break;
            }
        }

        try {
            $this->logger->debug("getPaydirektReport: REQUESTMODEL: ", $reportRequestModel);
            if ($type === "csv") {
                $reportCsv = Report::getReportCsv($token, $liveSystem, $reportRequestModel);
                $filename = "paydirekt_Transaktionen_Report";
                if (!empty($from)) {
                    $filename .= "_" . $from;
                }
                $filename .= "_" . $to;
                $filename .= ".csv";
                header('Content-Type: application/csv');
                header('Content-Disposition: attachment; filename="' . $filename . '";');
                header("Pragma: no-cache");
                header("Expires: 0");
                $f = fopen('php://output', 'w');
                fputs($f, $reportCsv[PAYDIREKT_RESPONSE]);
                fpassthru($f);
                die();
            } else {
                $report = Report::getReport($token, $liveSystem, $reportRequestModel);
                $_SESSION[PAYDIREKT_PAYDIREKTREPORT_SESSION_KEY]['shop_id'] = $shopId;
                $_SESSION[PAYDIREKT_PAYDIREKTREPORT_SESSION_KEY]['report_search_obj'] = serialize($reportRequestModel);
                $reportWithShopData = $this->addShopDataToReport($report[PAYDIREKT_RESPONSE]);

            }
        } catch (\Exception $e) {
            $this->logger->error("could not load report: ", array("error" => $e, "reportRequestModel" => $reportRequestModel));
        }

        $this->logger->debug("getPaydirektReport: END");
        return $reportWithShopData;
    }

    private function addShopDataToReport($report)
    {
        $this->logger->debug("addShopDataToReport: START");
        $decodedReport = json_decode($report, true);
        $encodedReport = null;
        $transactions = $decodedReport[PAYDIREKT_TRANSACTIONS];
        $hasOrder = false;
        for ($i = 0; $i < sizeof($transactions); $i++) {
            $order = null;
            $checkoutId = $transactions[$i][PAYDIREKT_CHECKOUT_ID];
            if (empty($checkoutId)) {
                continue;
            }
            $this->logger->debug("addShopDataToReport: Checkout ID", $checkoutId);
            $order = $this->getOrderByTransactionId($checkoutId);
            $this->logger->debug("addShopDataToReport: Order", $order);
            if ($order && !empty($order)) {
                $hasOrder = true;
                $transactions[$i][PAYDIREKT_PAYMENT_STATUS] = $order->get_status();
                $transactions[$i][PAYDIREKT_ORDER_STATUS] = $order->get_status();
                $transactions[$i][PAYDIREKT_ORDER_ID] = PAYDIREKT_COMPATIBILITY ? $order->id : $order->get_id();
                $transactions[$i][PAYDIREKT_SHOP_NAME] = "";
            }
        }

        if (!$hasOrder) {
            return $report;
        }
        $encodedReport[PAYDIREKT_TRANSACTIONS] = $transactions;
        $this->logger->debug("addShopDataToReport: END");
        return $encodedReport;
    }

    private function getOrderByTransactionId($transactionId)
    {
        $this->logger->debug("getOrderByTransactionId: START");
        $this->logger->debug("getOrderByTransactionId: TRANSACITON ID:", $transactionId);
        $this->logger->debug("getOrderByTransactionId: END");
        $order = null;
        $orders = null;
        $orderList = null;

        if (PAYDIREKT_COMPATIBILITY) {
            $args = array("limit" => -1);
            $orderList = \wc_get_orders($args);

            foreach ($orderList as $theOrder) {
                if ($theOrder->get_transaction_id() == $transactionId) {
                    $orders = $theOrder;
                }
            }
        } else {
            $params = array('transaction_id' => $transactionId);
            $query = new \WC_Order_Query($params);
            $orders = $query->get_orders();
        }
        if (!empty($orders)) {
            if (is_array($orders)) {
                $order = $orders[0];
            } else {
                $order = $orders;
            }
        }

        return $order;
    }

    public function getPaydirektColumns()
    {
        return array(
            PAYDIREKT_SHOP_NAME => __('Shop', PAYDIREKT_PAYMENT_ID),
            PAYDIREKT_TYPE_ID => __('Buchungstyp', PAYDIREKT_PAYMENT_ID),
            PAYDIREKT_TRANSACTION_AMOUNT => __('Betrag', PAYDIREKT_PAYMENT_ID),
            PAYDIREKT_TRANSACTION_DATE => __('Datum', PAYDIREKT_PAYMENT_ID),
            PAYDIREKT_CHECKOUTID => __('Checkout-ID', PAYDIREKT_PAYMENT_ID),
            PAYDIREKT_END_TO_END_REFERENCE_NUMBER => __('Transaktions-ID', PAYDIREKT_PAYMENT_ID),
            PAYDIREKT_MERCHANT_REFERENCE => __('Bestellnummer', PAYDIREKT_PAYMENT_ID),
            PAYDIREKT_RECONCILIATION_REFERENCE_NUMBER => __('Referenznummer', PAYDIREKT_PAYMENT_ID),
            PAYDIREKT_RECONCILIATION_REFERENCE_NUMBER => __('Reconciliationsnummer', PAYDIREKT_PAYMENT_ID),
            PAYDIREKT_PAYMENT_INFORMATION_ID => __('PaymentInformation-ID', PAYDIREKT_PAYMENT_ID),
            PAYDIREKT_ORDER_STATUS => __('Bestellstatus', PAYDIREKT_PAYMENT_ID),
            PAYDIREKT_PAYMENT_STATUS => __('Zahlstatus', PAYDIREKT_PAYMENT_ID),
            PAYDIREKT_ACTION => __('Aktion', PAYDIREKT_PAYMENT_ID),
        );
    }

    // override function
    public function renderColumn($column, $data, $rowData = null)
    {
        $columnData = $data;
        switch ($column) {
            case PAYDIREKT_TRANSACTION_DATE:
                $columnData = date("d.m.Y H:i:s", strtotime($data));
                break;
            case PAYDIREKT_TRANSACTION_AMOUNT:
                $columnData = number_format((float) $columnData, 2, ',', '') . " " . $rowData[PAYDIREKT_TRANSACTION_CURRENCY];
                break;
            case PAYDIREKT_STATUS:
            case PAYDIREKT_TYPE:
                $columnData = __($columnData, 'fulino-paydirekt');
                break;
            case PAYDIREKT_ACTION:
                if (isset($rowData[PAYDIREKT_ORDER_ID]) && !empty($rowData[PAYDIREKT_ORDER_ID])) {
                    $overview_url = wp_nonce_url(admin_url('admin.php?page=paydirekt-orderview&order_id=' . $rowData[PAYDIREKT_ORDER_ID]));
                    $columnData = '<a href="' . $overview_url . '" class="button button-primary">'
                    . __('to transaction', PAYDIREKT_PAYMENT_ID)
                        . '</a>';
                }
                // @todo: wenn es die bestellung im system gibt, verlinke zur Detail ansicht
                break;
            case PAYDIREKT_TYPE_ID:
                $columnData = constant("PAYDIREKT_TRANSACTION_TYPE_" . $columnData);
                break;
            case PAYDIREKT_RECONCILIATION_REFERENCE_NUMBER:
                if ($rowData[PAYDIREKT_MERCHANT_TRANSACTION_REFERENCE_NUMBER] != null) {
                    $columnData = $rowData[PAYDIREKT_MERCHANT_TRANSACTION_REFERENCE_NUMBER];
                }
                break;
            default:
                break;
        }
        return $columnData;
    }

    public function renderRow($rowIndex, $data, $columns)
    {
        if ($data[$rowIndex][PAYDIREKT_TYPE] == PAYDIREKT_CHECKOUT_TYPE_ORDER
            || $data[$rowIndex][PAYDIREKT_TYPE] == PAYDIREKT_CHECKOUT_TYPE_DIRECT_SALE
            || $data[$rowIndex][PAYDIREKT_TYPE] == PAYDIREKT_CHECKOUT_TYPE_ORDER_SECURED) {
            $transactionId = $data[$rowIndex][PAYDIREKT_CHECKOUTID];
        } else {
            $transactionId = $data[$rowIndex][PAYDIREKT_CORRELATION_ID];
        }

        $row = "<tr class='paydirekt-report paydirekt-report-row' data-paydirekt-id='"
        . $transactionId . "' data-paydirekt-type='"
        . $data[$rowIndex][PAYDIREKT_TYPE_ID] . "' data-paydirekt-checkoutid='"
        . $data[$rowIndex][PAYDIREKT_CHECKOUTID] . "' data-paydirekt-data='" . json_encode($data[$rowIndex]) . "'>";

        foreach ($columns as $columnIndex => $columnName) {
            if ((isset($data[$rowIndex][$columnIndex]) && !is_array($data[$rowIndex][$columnIndex])) || $columnIndex == PAYDIREKT_ACTION) {
                $renderData = $this->renderColumn($columnIndex, $data[$rowIndex][$columnIndex], $data[$rowIndex]);
                $row .= $this->renderCell($columnIndex, $renderData);
            } else {
                $row .= $this->renderCell($columnIndex, "");
            }
        }
        return $row . "</tr>";
    }

    public function renderCell($column, $data)
    {
        return "<td class='data-$column paydirekt-report-column'>$data</td>";
    }

    public function prepare_items()
    {
        $paydirektData = $this->getPaydirektData();
        $columns = $this->getPaydirektColumns();

        $this->setColumns($columns);
        if (isset($paydirektData[PAYDIREKT_TRANSACTIONS])) {
            $this->setData($paydirektData[PAYDIREKT_TRANSACTIONS]);
        }
    }
}
