<?php
/**
 * @category    Payment Plugin
 * @package     paydirekt
 * @author      Logata Digital Solutions GmbH
 * @copyright   Logata Digital Solutions GmbH
 * @license     https://logata.com/paydirekt-lizenzbedingungen
 * @version     1.0.44
 * @link        https://www.paydirekt.de
 */

namespace Bitergo\PaydirektWooCommerce\classes\components;

if (!defined('ABSPATH')) {
    exit;
}
class PaydirektTable
{

    private $columns;
    private $data;
    private $toolbarData;

    public function getColumns()
    {
        return $this->columns;
    }
    public function setColumns($columns)
    {
        $this->columns = $columns;
    }
    public function getData()
    {
        return $this->data;
    }
    public function setData($data)
    {
        $this->data = $data;
    }
    public function getToolbarData()
    {
        return $this->toolbar;
    }
    public function setToolbarData($toolbarData)
    {
        $this->toolbarData = $toolbarData;
    }

    public function render()
    {
        ?>
        <div class='wrap paydirekt-list-container' id="paydirekt-list-container">
            <table class='wp-list-table widefat striped paydirekt-list ' 
                data-sorting="true" 
                data-filtering="true" 
                data-paging="true" 
                data-paging-size="10">
                <thead>
                    <tr>
                        <?php foreach ($this->columns as $columnIndex => $columnName): ?>
                        <th class='index-<?php echo $columnIndex?> column-title'><?php echo $columnName?></th>
                        <?php endforeach;?>
                    </tr>
                </thead>
                <tbody>
                <?php for ($i = 0; $i < count($this->data); $i++): ?>
                    <?php echo wp_kses($this->renderRow($i, $this->data, $this->columns), wp_kses_allowed_html('post')); ?>
                <?php endfor;?>
                </tbody>
                <tfoot>
                    <tr>
                        <?php if ($this->toolbarData[PAYDIREKT_COUNT_CAPTURES] != 0): ?>
                        <th>
                            <?php echo $this->toolbarData[PAYDIREKT_COUNT_CAPTURES]?>
                            <?php echo _n("capture", "captures", $this->toolbarData[PAYDIREKT_COUNT_CAPTURES], PAYDIREKT_PAYMENT_ID)?>:
                        </th>
                        <th>
                            <?php echo number_format((float) $this->toolbarData[PAYDIREKT_SUM_CAPTURES], 2, ',', '')?> EUR
                        </th>
                        <th colspan=100>
                            <?php if (!empty($this->toolbarData[PAYDIREKT_REST_CAPTURABLE])): ?>
                                <?php echo __('still', PAYDIREKT_PAYMENT_ID)?>
                                <?php echo number_format((float) $this->toolbarData[PAYDIREKT_REST_CAPTURABLE], 2, ',', '');?> EUR
                                <?php echo __('capturable', PAYDIREKT_PAYMENT_ID)?>
                            <?php endif;?>
                            <?php if (!empty($this->toolbarData[PAYDIREKT_CAPTURABLE_TILL])): ?>
                                <?php echo __('till', PAYDIREKT_PAYMENT_ID)?>
                                <?php echo date("d.m.Y H:m", $this->toolbarData[PAYDIREKT_CAPTURABLE_TILL])?>
                            <?php endif;?>
                        </th>
                        <?php endif;?>
                    </tr>
                    <tr>
                        <?php if ($this->toolbarData[PAYDIREKT_COUNT_REFUNDS] != 0): ?>
                        <th>
                            <?php echo $this->toolbarData[PAYDIREKT_COUNT_REFUNDS]?>
                            <?php echo _n("refund", "refunds", $this->toolbarData[PAYDIREKT_COUNT_REFUNDS], PAYDIREKT_PAYMENT_ID)?>:
                        </th>
                        <th>
                            <?php echo number_format((float) $this->toolbarData[PAYDIREKT_SUM_REFUNDS], 2, ',', '')?> EUR
                        </th>
                        <th colspan=100>
                            <?php if (!empty($this->toolbarData[PAYDIREKT_REST_REFUNDS])): ?>
                                <?php echo __('still', PAYDIREKT_PAYMENT_ID)?>
                                <?php echo number_format((float) $this->toolbarData[PAYDIREKT_REST_REFUNDS], 2, ',', '');?> EUR
                                <?php echo __('refundable', PAYDIREKT_PAYMENT_ID)?>
                            <?php endif;?>
                        </th>
                        <?php endif;?>
                    </tr>
                </tfoot>
            </table>
        </div>
        <?php
    }

    protected function renderColumn($column, $data, $rowData=null)
    {
        return $data;
    }
    protected function renderCell($column, $data)
    {
        return "<td class='data-$column'>$data</td>";
    }
    protected function renderRow($rowIndex, $data, $columns)
    {
        $row = "</tr>";
        foreach ($columns as $columnIndex => $columnName) {
            if (isset($data[$rowIndex][$columnIndex]) && !is_array($data[$rowIndex][$columnIndex])) {
                $renderData = $this->renderColumn($columnIndex, $data[$rowIndex][$columnIndex]);
                $row .= $this->renderCell($columnIndex, $renderData);
            } else {
                $row .= $this->renderCell($columnIndex, "");
            }
        }
        return $row . "</tr>";
    }
}